# -*- coding: utf-8 -*-
# Copyright (c) 2021, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from __future__ import unicode_literals

from unittest import TestCase

from num2words import num2words

TEST_CASES_CARDINAL = (
    (1, "unu"),
    (2, "du"),
    (3, "tri"),
    (5.5, "kvin komo kvin"),
    (11, "dek unu"),
    (12, "dek du"),
    (16, "dek ses"),
    (17.42, "dek sep komo kvar du"),
    (19, "dek naŭ"),
    (20, "dudek"),
    (21, "dudek unu"),
    (26, "dudek ses"),
    (27.312, "dudek sep komo tri unu du"),
    (28, "dudek ok"),
    (30, "tridek"),
    (31, "tridek unu"),
    (40, "kvardek"),
    (44, "kvardek kvar"),
    (50, "kvindek"),
    (53.486, "kvindek tri komo kvar ok ses"),
    (55, "kvindek kvin"),
    (60, "sesdek"),
    (67, "sesdek sep"),
    (70, "sepdek"),
    (79, "sepdek naŭ"),
    (89, "okdek naŭ"),
    (95, "naŭdek kvin"),
    (100, "cent"),
    (101, "cent unu"),
    (199, "cent naŭdek naŭ"),
    (203, "ducent tri"),
    (287, "ducent okdek sep"),
    (300.42, "tricent komo kvar du"),
    (356, "tricent kvindek ses"),
    (400, "kvarcent"),
    (434, "kvarcent tridek kvar"),
    (578, "kvincent sepdek ok"),
    (689, "sescent okdek naŭ"),
    (729, "sepcent dudek naŭ"),
    (894, "okcent naŭdek kvar"),
    (999, "naŭcent naŭdek naŭ"),
    (1000, "mil"),
    (1001, "mil unu"),
    (1097, "mil naŭdek sep"),
    (1104, "mil cent kvar"),
    (1243, "mil ducent kvardek tri"),
    (2385, "du mil tricent okdek kvin"),
    (3766, "tri mil sepcent sesdek ses"),
    (4196, "kvar mil cent naŭdek ses"),
    (4196.42, "kvar mil cent naŭdek ses komo kvar du"),
    (5846, "kvin mil okcent kvardek ses"),
    (6459, "ses mil kvarcent kvindek naŭ"),
    (7232, "sep mil ducent tridek du"),
    (8569, "ok mil kvincent sesdek naŭ"),
    (9539, "naŭ mil kvincent tridek naŭ"),
    (1000000, "unu miliono"),
    (1000001, "unu miliono unu"),
    (4000000, "kvar milionoj"),
    (4000004, "kvar milionoj kvar"),
    (4300000, "kvar milionoj tricent mil"),
    (80000000, "okdek milionoj"),
    (300000000, "tricent milionoj"),
    (10000000000000, "dek bilionoj"),
    (10000000000010, "dek bilionoj dek"),
    (100000000000000, "cent bilionoj"),
    (1000000000000000000, "unu triliono"),
    (1000000000000000000000, "unu triliardo"),
    (10000000000000000000000000, "dek kvarilionoj")
)

TEST_CASES_ORDINAL = (
    (1, "unua"),
    (8, "oka"),
    (12, "dek dua"),
    (14, "dek kvara"),
    (28, "dudek oka"),
    (100, "centa"),
    (1000, "mila"),
    (1000000, "unu miliona"),
    (1000000000000000, "unu biliarda"),
    (1000000000000000000, "unu triliona")
)

TEST_CASES_ORDINAL_NUM = (
    (1, "1a"),
    (8, "8a"),
    (11, "11a"),
    (12, "12a"),
    (14, "14a"),
    (21, "21a"),
    (28, "28a"),
    (100, "100a"),
    (101, "101a"),
    (1000, "1000a"),
    (1000000, "1000000a")
)

TEST_CASES_TO_CURRENCY_EUR = (
    (1.00, "unu eŭro kaj nul centimo"),
    (2.01, "du eŭroj kaj unu centimo"),
    (8.10, "ok eŭroj kaj dek centimoj"),
    (12.26, "dek du eŭroj kaj dudek ses centimoj"),
    (21.29, "dudek unu eŭroj kaj dudek naŭ centimoj"),
    (81.25, "okdek unu eŭroj kaj dudek kvin centimoj"),
    (100.00, "cent eŭroj kaj nul centimo"),
)

TEST_CASES_TO_CURRENCY_FRF = (
    (1.00, "unu franko kaj nul centimo"),
    (2.01, "du frankoj kaj unu centimo"),
    (8.10, "ok frankoj kaj dek centimoj"),
    (12.27, "dek du frankoj kaj dudek sep centimoj"),
    (21.29, "dudek unu frankoj kaj dudek naŭ centimoj"),
    (81.25, "okdek unu frankoj kaj dudek kvin centimoj"),
    (100.00, "cent frankoj kaj nul centimo"),
)

TEST_CASES_TO_CURRENCY_USD = (
    (1.00, "unu dolaro kaj nul cendo"),
    (2.01, "du dolaroj kaj unu cendo"),
    (8.10, "ok dolaroj kaj dek cendoj"),
    (12.26, "dek du dolaroj kaj dudek ses cendoj"),
    (21.29, "dudek unu dolaroj kaj dudek naŭ cendoj"),
    (81.25, "okdek unu dolaroj kaj dudek kvin cendoj"),
    (100.00, "cent dolaroj kaj nul cendo"),
)


class Num2WordsEOTest(TestCase):
    def test_number(self):
        for test in TEST_CASES_CARDINAL:
            self.assertEqual(num2words(test[0], lang="eo"), test[1])

    def test_ordinal(self):
        for test in TEST_CASES_ORDINAL:
            self.assertEqual(
                num2words(test[0], lang="eo", ordinal=True),
                test[1]
            )

    def test_ordinal_num(self):
        for test in TEST_CASES_ORDINAL_NUM:
            self.assertEqual(
                num2words(test[0], lang="eo", to="ordinal_num"),
                test[1]
            )

    def test_currency_eur(self):
        for test in TEST_CASES_TO_CURRENCY_EUR:
            self.assertEqual(
                num2words(test[0], lang="eo", to="currency", currency="EUR"),
                test[1]
            )

    def test_currency_frf(self):
        for test in TEST_CASES_TO_CURRENCY_FRF:
            self.assertEqual(
                num2words(test[0], lang="eo", to="currency", currency="FRF"),
                test[1]
            )

    def test_currency_usd(self):
        for test in TEST_CASES_TO_CURRENCY_USD:
            self.assertEqual(
                num2words(test[0], lang="eo", to="currency", currency="USD"),
                test[1]
            )



# -*- coding: utf-8 -*-
# Copyright (c) 2021, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from __future__ import print_function, unicode_literals

from .base import Num2Word_Base


class Num2Word_EO(Num2Word_Base):
    CURRENCY_FORMS = {
        "EUR": (("eŭro", "eŭroj"), ("centimo", "centimoj")),
        "USD": (("dolaro", "dolaroj"), ("cendo", "cendoj")),
        "FRF": (("franko", "frankoj"), ("centimo", "centimoj")),
        "GBP": (("pundo", "pundoj"), ("penco", "pencoj")),
        "CNY": (("juano", "juanoj"), ("feno", "fenoj")),
    }

    GIGA_SUFFIX = "iliardo"
    MEGA_SUFFIX = "iliono"

    def set_high_numwords(self, high):
        cap = 3 + 6 * len(high)

        for word, n in zip(high, range(cap, 3, -6)):
            if self.GIGA_SUFFIX:
                self.cards[10 ** n] = word + self.GIGA_SUFFIX

            if self.MEGA_SUFFIX:
                self.cards[10 ** (n - 3)] = word + self.MEGA_SUFFIX

    def gen_high_numwords(self, units, tens, lows):
        out = [u + t for t in tens for u in units]
        out.reverse()
        return out + lows

    def setup(self):
        lows = ["naŭ", "ok", "sep", "ses", "kvin", "kvar", "tr", "b", "m"]
        units = ["", "un", "duo", "tre", "kvatuor",
                 "kvin", "seks", "septen", "okto", "novem"]
        tens = ["dek", "vigint", "trigint", "kvadragint", "kvinkvagint",
                "seksagint", "septuagint", "oktogint", "nonagint"]

        self.high_numwords = ["cent"] + self.gen_high_numwords(units, tens,
                                                               lows)

        self.negword = "minus "
        self.pointword = "komo"
        self.errmsg_nonnum = u"Sole nombroj povas esti konvertita en vortojn."
        self.errmsg_toobig = (
            u"Tro granda nombro por esti konvertita en vortojn (abs(%s) > %s)."
        )
        self.exclude_title = ["kaj", "komo", "minus"]
        self.mid_numwords = [(1000, "mil"), (100, "cent"), (90, "naŭdek"),
                             (80, "okdek"), (70, "sepdek"), (60, "sesdek"),
                             (50, "kvindek"), (40, "kvardek"), (30, "tridek")]
        self.low_numwords = ["dudek", "dek naŭ", "dek ok", "dek sep",
                             "dek ses", "dek kvin", "dek kvar", "dek tri",
                             "dek du", "dek unu", "dek", "naŭ", "ok", "sep",
                             "ses", "kvin", "kvar", "tri", "du", "unu", "nul"]
        self.ords = {
            "unu": "unua",
            "du": "dua",
            "tri": "tria",
            "kvar": "kvara",
            "kvin": "kvina",
            "ses": "sesa",
            "sep": "sepa",
            "ok": "oka",
            "naŭ": "naŭa",
            "dek": "deka"
        }

    def merge(self, curr, next):
        ctext, cnum, ntext, nnum = curr + next
        if cnum == 1 and nnum < 1000000:
            return next

        if nnum >= 10**6 and cnum > 1:
            return ("%s %sj" % (ctext, ntext), cnum + nnum)

        if nnum == 100:
            return ("%s%s" % (ctext, ntext), cnum + nnum)

        return ("%s %s" % (ctext, ntext), cnum + nnum)

    def to_ordinal(self, value):
        self.verify_ordinal(value)
        word = self.to_cardinal(value)
        for src, repl in self.ords.items():
            if word.endswith(src):
                word = word[:-len(src)] + repl
                return word

        if word.endswith("o"):
            word = word[:-1] + "a"
        elif word.endswith("oj"):
            word = word[:-2] + "a"
        else:
            word = word + "a"
        return word

    def to_ordinal_num(self, value):
        self.verify_ordinal(value)
        out = str(value)
        out += "a"
        return out

    def to_currency(self, val, currency="EUR", cents=True, separator=" kaj",
                    adjective=False):
        result = super(Num2Word_EO, self).to_currency(
            val, currency=currency, cents=cents, separator=separator,
            adjective=adjective)
        return result

    def pluralize(self, n, forms):
        form = 0 if n <= 1 else 1
        return forms[form]



# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from __future__ import unicode_literals

from unittest import TestCase

from num2words import num2words
from num2words.lang_HE import Num2Word_HE, int2word


class Num2WordsHETest(TestCase):
    maxDiff = None

    def test_negative(self):
        self.assertEqual(num2words(-1, lang="he"), u'מינוס אחת')

    def test_0(self):
        self.assertEqual(num2words(0, lang="he"), u'אפס')

    def test_1_to_10(self):
        self.assertEqual(num2words(1, lang="he"), u'אחת')
        self.assertEqual(num2words(2, lang="he"), u'שתיים')
        self.assertEqual(num2words(7, lang="he"), u'שבע')
        self.assertEqual(num2words(10, lang="he"), u'עשר')
        self.assertEqual(num2words(
            10, lang="he", gender='m', construct=True), u'עשרת')

    def test_11_to_19(self):
        self.assertEqual(num2words(11, lang="he"), u'אחת עשרה')
        self.assertEqual(num2words(11, lang="he", gender='m'), u'אחד עשר')
        self.assertEqual(num2words(13, lang="he"), u'שלוש עשרה')
        self.assertEqual(num2words(
            13, lang="he", construct=True), u'שלוש עשרה')
        self.assertEqual(num2words(15, lang="he"), u'חמש עשרה')
        self.assertEqual(num2words(16, lang="he"), u'שש עשרה')
        self.assertEqual(num2words(16, lang="he", gender='m'), u'שישה עשר')
        self.assertEqual(num2words(
            16, lang="he", gender='m', construct=True), u'שישה עשר')
        self.assertEqual(num2words(19, lang="he"), u'תשע עשרה')

    def test_20_to_99(self):
        self.assertEqual(num2words(20, lang="he"), u'עשרים')
        self.assertEqual(num2words(23, lang="he"), u'עשרים ושלוש')
        self.assertEqual(num2words(23, lang="he", gender='m'), u'עשרים ושלושה')
        self.assertEqual(num2words(
            23, lang="he", construct=True), u'עשרים ושלוש')
        self.assertEqual(num2words(
            23, lang="he", gender='m', construct=True), u'עשרים ושלושה')
        self.assertEqual(num2words(28, lang="he"), u'עשרים ושמונה')
        self.assertEqual(num2words(31, lang="he"), u'שלושים ואחת')
        self.assertEqual(num2words(40, lang="he"), u'ארבעים')
        self.assertEqual(num2words(66, lang="he"), u'שישים ושש')
        self.assertEqual(num2words(92, lang="he"), u'תשעים ושתיים')

    def test_100_to_999(self):
        self.assertEqual(num2words(100, lang="he"), u'מאה')
        self.assertEqual(num2words(100, lang="he", construct=True), u'מאת')
        self.assertEqual(num2words(111, lang="he"), u'מאה ואחת עשרה')
        self.assertEqual(num2words(
            111, lang="he", construct=True), u'מאה ואחת עשרה')
        self.assertEqual(num2words(150, lang="he"), u'מאה וחמישים')
        self.assertEqual(num2words(196, lang="he"), u'מאה תשעים ושש')
        self.assertEqual(num2words(
            196, lang="he", gender='m'), u'מאה תשעים ושישה')
        self.assertEqual(num2words(
            196, lang="he", gender='m', construct=True), u'מאה תשעים ושישה')
        self.assertEqual(num2words(200, lang="he"), u'מאתיים')
        self.assertEqual(num2words(200, lang="he", construct=True), u'מאתיים')
        self.assertEqual(num2words(210, lang="he"), u'מאתיים ועשר')
        self.assertEqual(num2words(701, lang="he"), u'שבע מאות ואחת')

    def test_1000_to_9999(self):
        self.assertEqual(num2words(1000, lang="he"), u'אלף')
        self.assertEqual(num2words(1000, lang="he", construct=True), u'אלף')
        self.assertEqual(num2words(1001, lang="he"), u'אלף ואחת')
        self.assertEqual(num2words(1002, lang="he"), u'אלף ושתיים')
        self.assertEqual(num2words(1002, lang="he", gender='m'), u'אלף ושניים')
        self.assertEqual(num2words(
            1002, lang="he", gender='m', construct=True), u'אלף ושניים')
        self.assertEqual(num2words(1003, lang="he"), u'אלף ושלוש')
        self.assertEqual(num2words(1003, lang="he", gender='m'), u'אלף ושלושה')
        self.assertEqual(num2words(
            1003, lang="he", gender='m', construct=True), u'אלף ושלושה')
        self.assertEqual(num2words(1010, lang="he"), u'אלף ועשר')
        self.assertEqual(num2words(1010, lang="he", gender='m'), u'אלף ועשרה')
        self.assertEqual(num2words(
            1010, lang="he", gender='m', construct=True), u'אלף ועשרה')
        self.assertEqual(num2words(1500, lang="he"), u'אלף וחמש מאות')
        self.assertEqual(num2words(2000, lang="he"), u'אלפיים')
        self.assertEqual(num2words(2000, lang="he", construct=True), u'אלפיים')
        self.assertEqual(num2words(2002, lang="he"), u'אלפיים ושתיים')
        self.assertEqual(num2words(
            2002, lang="he", construct=True), u'אלפיים ושתיים')
        self.assertEqual(num2words(3000, lang="he"), u'שלושת אלפים')
        self.assertEqual(num2words(
            3000, lang="he", construct=True), u'שלושת אלפי')
        self.assertEqual(num2words(3001, lang="he"), u'שלושת אלפים ואחת')
        self.assertEqual(num2words(
            3001, lang="he", construct=True), u'שלושת אלפים ואחת')
        self.assertEqual(num2words(3100, lang="he"), u'שלושת אלפים ומאה')
        self.assertEqual(num2words(
            3100, lang="he", construct=True), u'שלושת אלפים ומאה')
        self.assertEqual(num2words(
            6870, lang="he"), u'ששת אלפים שמונה מאות ושבעים')
        self.assertEqual(num2words(
            7378, lang="he"), u'שבעת אלפים שלוש מאות שבעים ושמונה')
        self.assertEqual(num2words(
            9999, lang="he"), u'תשעת אלפים תשע מאות תשעים ותשע')

    def test_10000_to_99999(self):
        self.assertEqual(num2words(10000, lang="he"), u'עשרת אלפים')
        self.assertEqual(num2words(
            10000, lang="he", construct=True), u'עשרת אלפי')
        self.assertEqual(num2words(10001, lang="he"), u'עשרת אלפים ואחת')
        self.assertEqual(num2words(
            10001, lang="he", construct=True), u'עשרת אלפים ואחת')
        self.assertEqual(num2words(
            10999, lang="he"), u'עשרת אלפים תשע מאות תשעים ותשע')
        self.assertEqual(num2words(11000, lang="he"), u'אחד עשר אלף')
        self.assertEqual(num2words(15000, lang="he"), u'חמישה עשר אלף')
        self.assertEqual(num2words(
            15000, lang="he", gender='m'), u'חמישה עשר אלף')
        self.assertEqual(num2words(20000, lang="he"), u'עשרים אלף')
        self.assertEqual(num2words(
            20000, lang="he", construct=True), u'עשרים אלף')
        self.assertEqual(num2words(21000, lang="he"), u'עשרים ואחד אלף')
        self.assertEqual(num2words(25000, lang="he"), u'עשרים וחמישה אלף')
        self.assertEqual(num2words(
            25000, lang="he", construct=True), u'עשרים וחמישה אלף')
        self.assertEqual(num2words(
            68700, lang="he"), u'שישים ושמונה אלף ושבע מאות')
        self.assertEqual(num2words(
            73781, lang="he"), u'שבעים ושלושה אלף שבע מאות שמונים ואחת')
        self.assertEqual(num2words(
            99999, lang="he"), u'תשעים ותשעה אלף תשע מאות תשעים ותשע')

    def test_100000_to_999999(self):
        self.assertEqual(num2words(100000, lang="he"), u'מאה אלף')
        self.assertEqual(num2words(
            100000, lang="he", construct=True), u'מאה אלף')
        self.assertEqual(num2words(100001, lang="he"), u'מאה אלף ואחת')
        self.assertEqual(num2words(
            199999, lang="he"), u'מאה תשעים ותשעה אלף תשע מאות תשעים ותשע')
        self.assertEqual(num2words(110000, lang="he"), u'מאה ועשרה אלף')
        self.assertEqual(num2words(150000, lang="he"), u'מאה וחמישים אלף')
        self.assertEqual(num2words(200000, lang="he"), u'מאתיים אלף')
        self.assertEqual(num2words(210000, lang="he"), u'מאתיים ועשרה אלף')
        self.assertEqual(num2words(
            687000, lang="he"), u'שש מאות שמונים ושבעה אלף')
        self.assertEqual(num2words(
            687000, lang="he", construct=True), u'שש מאות שמונים ושבעה אלף')
        self.assertEqual(num2words(737812, lang="he"),
                         u'שבע מאות שלושים ושבעה אלף שמונה מאות ושתים עשרה')
        self.assertEqual(num2words(999999, lang="he"),
                         u'תשע מאות תשעים ותשעה אלף תשע מאות תשעים ותשע')

    def test_1000000_to_999999999999999(self):
        self.assertEqual(num2words(1000000, lang="he"), u'מיליון')
        self.assertEqual(num2words(
            1000000, lang="he", construct=True), u'מיליון')
        self.assertEqual(num2words(1000002, lang="he"), u'מיליון ושתיים')
        self.assertEqual(num2words(
            1000002, lang="he", construct=True), u'מיליון ושתיים')
        self.assertEqual(num2words(2000000, lang="he"), u'שני מיליון')
        self.assertEqual(num2words(
            2000000, lang="he", construct=True), u'שני מיליוני')
        self.assertEqual(num2words(3000000, lang="he"), u'שלושה מיליון')
        self.assertEqual(num2words(
            3000000, lang="he", construct=True), u'שלושת מיליוני')
        self.assertEqual(num2words(3000002, lang="he"), u'שלושה מיליון ושתיים')
        self.assertEqual(num2words(
            3000002, lang="he", construct=True), u'שלושה מיליון ושתיים')
        self.assertEqual(num2words(10000000, lang="he"), u'עשרה מיליון')
        self.assertEqual(num2words(
            10000000, lang="he", construct=True), 'עשרת מיליוני')
        self.assertEqual(num2words(11000000, lang="he"), u'אחד עשר מיליון')
        self.assertEqual(num2words(
            11000000, lang="he", construct=True), 'אחד עשר מיליוני')

        self.assertEqual(num2words(1000000000, lang="he"), u'מיליארד')
        self.assertEqual(num2words(
            1000000000, lang="he", construct=True), u'מיליארד')
        self.assertEqual(num2words(1000000002, lang="he"), u'מיליארד ושתיים')
        self.assertEqual(num2words(
            1000000002, lang="he", construct=True), u'מיליארד ושתיים')
        self.assertEqual(num2words(2000000000, lang="he"), u'שני מיליארד')
        self.assertEqual(num2words(
            2000000000, lang="he", construct=True), u'שני מיליארדי')
        self.assertEqual(num2words(3000000000, lang="he"), u'שלושה מיליארד')
        self.assertEqual(num2words(
            3000000000, lang="he", construct=True), u'שלושת מיליארדי')
        self.assertEqual(num2words(
            3000000002, lang="he"), u'שלושה מיליארד ושתיים')
        self.assertEqual(num2words(
            3000000002, lang="he", construct=True), u'שלושה מיליארד ושתיים')
        self.assertEqual(num2words(10000000000, lang="he"), u'עשרה מיליארד')
        self.assertEqual(num2words(
            10000000000, lang="he", construct=True), 'עשרת מיליארדי')
        self.assertEqual(num2words(
            10000000002, lang="he"), u'עשרה מיליארד ושתיים')
        self.assertEqual(num2words(
            10000000002, lang="he", construct=True), 'עשרה מיליארד ושתיים')
        self.assertEqual(num2words(11000000000, lang="he"), u'אחד עשר מיליארד')
        self.assertEqual(num2words(
            11000000000, lang="he", construct=True), 'אחד עשר מיליארדי')

        self.assertEqual(num2words(1000000000000, lang="he"), u'טריליון')
        self.assertEqual(num2words(
            1000000000000, lang="he", construct=True), u'טריליון')
        self.assertEqual(num2words(
            1000000000002, lang="he"), u'טריליון ושתיים')
        self.assertEqual(num2words(
            1000000000002, lang="he", construct=True), u'טריליון ושתיים')
        self.assertEqual(num2words(2000000000000, lang="he"), u'שני טריליון')
        self.assertEqual(num2words(
            2000000000000, lang="he", construct=True), u'שני טריליוני')
        self.assertEqual(num2words(3000000000000, lang="he"), u'שלושה טריליון')
        self.assertEqual(num2words(
            3000000000000, lang="he", construct=True), u'שלושת טריליוני')
        self.assertEqual(num2words(
            3000000000002, lang="he"), u'שלושה טריליון ושתיים')
        self.assertEqual(num2words(
            3000000000002, lang="he", construct=True), u'שלושה טריליון ושתיים')
        self.assertEqual(num2words(10000000000000, lang="he"), u'עשרה טריליון')
        self.assertEqual(num2words(
            10000000000000, lang="he", construct=True), 'עשרת טריליוני')
        self.assertEqual(num2words(
            10000000000002, lang="he"), u'עשרה טריליון ושתיים')
        self.assertEqual(num2words(
            10000000000002, lang="he", construct=True), 'עשרה טריליון ושתיים')
        self.assertEqual(num2words(
            11000000000000, lang="he"), u'אחד עשר טריליון')
        self.assertEqual(num2words(
            11000000000000, lang="he", construct=True), 'אחד עשר טריליוני')

        self.assertEqual(num2words(999999999999999, lang="he"),
                         u'תשע מאות תשעים ותשעה טריליון '
                         u'תשע מאות תשעים ותשעה מיליארד '
                         u'תשע מאות תשעים ותשעה מיליון '
                         u'תשע מאות תשעים ותשעה אלף תשע מאות תשעים ותשע')
        self.assertEqual(num2words(999999999999999, lang="he", gender='m'),
                         u'תשע מאות תשעים ותשעה טריליון '
                         u'תשע מאות תשעים ותשעה מיליארד '
                         u'תשע מאות תשעים ותשעה מיליון '
                         u'תשע מאות תשעים ותשעה אלף תשע מאות תשעים ותשעה')
        self.assertEqual(num2words(999999999999999, lang="he", construct=True),
                         u'תשע מאות תשעים ותשעה טריליון '
                         u'תשע מאות תשעים ותשעה מיליארד '
                         u'תשע מאות תשעים ותשעה מיליון '
                         u'תשע מאות תשעים ותשעה אלף תשע מאות תשעים ותשע')
        self.assertEqual(num2words(
            999999999999999, lang="he", gender='m', construct=True),
            u'תשע מאות תשעים ותשעה טריליון '
            u'תשע מאות תשעים ותשעה מיליארד '
            u'תשע מאות תשעים ותשעה מיליון '
            u'תשע מאות תשעים ותשעה אלף תשע מאות תשעים ותשעה')

    def test_pluralize(self):
        n = Num2Word_HE()
        cr1, cr2 = n.CURRENCY_FORMS['ILS']
        self.assertEqual(n.pluralize(1, cr1), u'שקל')
        self.assertEqual(n.pluralize(2, cr1), u'שקלים')
        self.assertEqual(n.pluralize(1, cr2), u'אגורה')
        self.assertEqual(n.pluralize(2, cr2), u'אגורות')

        cr1, cr2 = n.CURRENCY_FORMS['USD']
        self.assertEqual(n.pluralize(1, cr1), u'דולר')
        self.assertEqual(n.pluralize(2, cr1), u'דולרים')
        self.assertEqual(n.pluralize(1, cr2), u'סנט')
        self.assertEqual(n.pluralize(2, cr2), u'סנטים')

    def test_to_currency(self):
        n = Num2Word_HE()
        self.assertEqual(n.to_currency(
            20.0, currency='ILS'), u'עשרים שקלים ואפס אגורות')
        self.assertEqual(n.to_currency(
            100.0, currency='ILS'), u'מאה שקלים ואפס אגורות')
        self.assertEqual(n.to_currency(
            100.50, currency='ILS'), u'מאה שקלים וחמישים אגורות')
        self.assertEqual(n.to_currency(
            101.51, currency='ILS'), u'מאה ואחד שקלים וחמישים ואחת אגורות')
        self.assertEqual(n.to_currency(
            -101.51, currency='ILS'),
            u'מינוס מאה ואחד שקלים וחמישים ואחת אגורות')
        self.assertEqual(n.to_currency(
            -101.51, currency='ILS', prefer_singular=True),
            u'מינוס מאה ואחד שקל וחמישים ואחת אגורות')
        self.assertEqual(n.to_currency(
            -101.51, currency='ILS', prefer_singular_cents=True),
            u'מינוס מאה ואחד שקלים וחמישים ואחת אגורה')
        self.assertEqual(n.to_currency(
            -101.51, currency='ILS', prefer_singular=True,
            prefer_singular_cents=True),
            u'מינוס מאה ואחד שקל וחמישים ואחת אגורה')
        self.assertEqual(n.to_currency(
            5.05, currency='ILS', prefer_singular=True,
            prefer_singular_cents=True), u'חמישה שקלים וחמש אגורות')
        self.assertEqual(n.to_currency(
            -5.05, currency='ILS', prefer_singular=True,
            prefer_singular_cents=True), u'מינוס חמישה שקלים וחמש אגורות')
        self.assertEqual(n.to_currency(
            -5.05, currency='ILS', cents=False),
            u'מינוס חמישה שקלים ו-05 אגורות')
        self.assertEqual(n.to_currency(
            -5.05, currency='ILS', cents=False, separator='ו'),
            u'מינוס חמישה שקלים ו-05 אגורות')
        self.assertEqual(n.to_currency(
            -5.05, currency='ILS', cents=False, separator='ו-'),
            u'מינוס חמישה שקלים ו-05 אגורות')
        self.assertEqual(n.to_currency(
            -5.05, currency='ILS', cents=False, separator=''),
            u'מינוס חמישה שקלים 05 אגורות')
        self.assertEqual(n.to_currency(
            -5.05, currency='ILS', cents=False, separator='ועוד '),
            u'מינוס חמישה שקלים ועוד 05 אגורות')
        self.assertEqual(n.to_currency(
            -5.05, currency='ILS', cents=False, separator=' ו'),
            u'מינוס חמישה שקלים ו-05 אגורות')
        self.assertEqual(n.to_currency(
            -5.05, currency='ILS', cents=False, separator=' ו-'),
            u'מינוס חמישה שקלים ו-05 אגורות')
        self.assertEqual(n.to_currency(
            -5.05, currency='ILS', cents=False, separator=' '),
            u'מינוס חמישה שקלים 05 אגורות')
        self.assertEqual(n.to_currency(
            -5.05, currency='ILS', cents=False, separator=' ועוד '),
            u'מינוס חמישה שקלים ועוד 05 אגורות')
        self.assertEqual(n.to_currency(
            1.01, currency='ILS'), u'שקל אחד ואגורה אחת')
        self.assertEqual(n.to_currency(
            -1.01, currency='ILS'), u'מינוס שקל אחד ואגורה אחת')
        self.assertEqual(n.to_currency(
            2.02, currency='ILS'), u'שני שקלים ושתי אגורות')
        self.assertEqual(n.to_currency(
            1002.02, currency='ILS'), u'אלף ושניים שקלים ושתי אגורות')
        self.assertEqual(n.to_currency(
            1000002.02, currency='ILS'), u'מיליון ושניים שקלים ושתי אגורות')
        self.assertEqual(n.to_currency(
            5.05, currency='USD'), u'חמישה דולרים וחמישה סנטים')
        self.assertEqual(n.to_currency(
            5.05, currency='USD', prefer_singular=True),
            u'חמישה דולר וחמישה סנטים')
        self.assertEqual(n.to_currency(
            5.05, currency='USD', prefer_singular_cents=True),
            u'חמישה דולרים וחמישה סנט')
        self.assertEqual(n.to_currency(
            5.05, currency='USD', prefer_singular=True,
            prefer_singular_cents=True), u'חמישה דולר וחמישה סנט')
        n.CURRENCY_FORMS['pruta'] = (('פרוטה', 'פרוטות'), ('מאית', 'מאיות'))
        self.assertEqual(n.to_currency(
            5.05, currency='pruta'), u'חמש פרוטות וחמש מאיות')

    def test_to_currency_errors(self):
        n = Num2Word_HE()
        with self.assertRaises(NotImplementedError):
            n.to_currency(1, '')

    def test_to_cardinal(self):
        n = Num2Word_HE()
        self.assertEqual(n.to_cardinal(1500), u'אלף וחמש מאות')
        self.assertEqual(n.to_cardinal(1501), u'אלף חמש מאות ואחת')
        self.assertEqual(num2words(1, lang='he'), u'אחת')
        self.assertEqual(num2words(1, lang='he', gender='m'), u'אחד')

    def test_to_ordinal(self):
        n = Num2Word_HE()
        self.assertEqual(n.to_ordinal(1001), u'האלף ואחד')
        self.assertEqual(n.to_ordinal(1500), u'האלף וחמש מאות')
        self.assertEqual(n.to_ordinal(1501), u'האלף חמש מאות ואחד')
        self.assertEqual(n.to_ordinal(
            1501, definite=True), u'האלף חמש מאות ואחד')
        self.assertEqual(n.to_ordinal(1), u'ראשון')
        self.assertEqual(n.to_ordinal(1, definite=True), u'הראשון')
        self.assertEqual(n.to_ordinal(1, gender='f'), u'ראשונה')
        self.assertEqual(n.to_ordinal(
            1, gender='f', definite=True), u'הראשונה')
        self.assertEqual(n.to_ordinal(10), u'עשירי')
        self.assertEqual(n.to_ordinal(10, definite=True), u'העשירי')
        self.assertEqual(n.to_ordinal(10, gender='f'), u'עשירית')
        self.assertEqual(n.to_ordinal(
            10, gender='f', definite=True), u'העשירית')
        self.assertEqual(n.to_ordinal(17), u'השבעה עשר')
        self.assertEqual(n.to_ordinal(17, definite=True), u'השבעה עשר')
        self.assertEqual(n.to_ordinal(17, gender='f'), u'השבע עשרה')
        self.assertEqual(n.to_ordinal(
            17, gender='f', definite=True), u'השבע עשרה')
        self.assertEqual(n.to_ordinal(0), u'האפס')
        self.assertEqual(n.to_ordinal(0, definite=True), u'האפס')
        self.assertEqual(n.to_ordinal(0, gender='f'), u'האפס')
        self.assertEqual(n.to_ordinal(0, gender='f', definite=True), u'האפס')
        self.assertEqual(n.to_ordinal(
            999999), u'התשע מאות תשעים ותשעה אלף תשע מאות תשעים ותשעה')
        self.assertEqual(n.to_ordinal(
            999999, gender='f'),
            u'התשע מאות תשעים ותשעה אלף תשע מאות תשעים ותשע')
        self.assertEqual(num2words(1, ordinal=True, lang='he'), u'ראשון')
        self.assertEqual(num2words(
            1, ordinal=True, lang='he', gender='f'), u'ראשונה')
        self.assertEqual(num2words(
            1, ordinal=True, lang='he', definite=True), u'הראשון')
        self.assertEqual(num2words(
            1, ordinal=True, lang='he', gender='f', definite=True), u'הראשונה')

    def test_to_ordinal_plural(self):
        n = Num2Word_HE()
        self.assertEqual(n.to_ordinal(1001, plural=True), u'האלף ואחד')
        self.assertEqual(n.to_ordinal(1500, plural=True), u'האלף וחמש מאות')
        self.assertEqual(n.to_ordinal(
            1501, plural=True), u'האלף חמש מאות ואחד')
        self.assertEqual(n.to_ordinal(
            1501, definite=True, plural=True), u'האלף חמש מאות ואחד')
        self.assertEqual(n.to_ordinal(1, plural=True), u'ראשונים')
        self.assertEqual(n.to_ordinal(
            1, definite=True, plural=True), u'הראשונים')
        self.assertEqual(n.to_ordinal(1, gender='f', plural=True), u'ראשונות')
        self.assertEqual(n.to_ordinal(
            1, gender='f', definite=True, plural=True), u'הראשונות')
        self.assertEqual(n.to_ordinal(10, plural=True), u'עשיריים')
        self.assertEqual(n.to_ordinal(
            10, definite=True, plural=True), u'העשיריים')
        self.assertEqual(n.to_ordinal(
            10, gender='f', plural=True), u'עשיריות')
        self.assertEqual(n.to_ordinal(
            10, gender='f', definite=True, plural=True), u'העשיריות')
        self.assertEqual(n.to_ordinal(17, plural=True), u'השבעה עשר')
        self.assertEqual(n.to_ordinal(
            17, definite=True, plural=True), u'השבעה עשר')
        self.assertEqual(n.to_ordinal(
            17, gender='f', plural=True), u'השבע עשרה')
        self.assertEqual(n.to_ordinal(
            17, gender='f', definite=True, plural=True), u'השבע עשרה')
        self.assertEqual(n.to_ordinal(0, plural=True), u'האפס')
        self.assertEqual(n.to_ordinal(0, definite=True, plural=True), u'האפס')
        self.assertEqual(n.to_ordinal(0, gender='f', plural=True), u'האפס')
        self.assertEqual(n.to_ordinal(
            0, gender='f', definite=True, plural=True), u'האפס')
        self.assertEqual(n.to_ordinal(999999, plural=True),
                         u'התשע מאות תשעים ותשעה אלף תשע מאות תשעים ותשעה')
        self.assertEqual(n.to_ordinal(999999, gender='f', plural=True),
                         u'התשע מאות תשעים ותשעה אלף תשע מאות תשעים ותשע')
        self.assertEqual(num2words(
            1, ordinal=True, lang='he', plural=True), u'ראשונים')
        self.assertEqual(num2words(
            1, ordinal=True, lang='he', gender='f', plural=True), u'ראשונות')
        self.assertEqual(num2words(1, ordinal=True, lang='he',
                                   definite=True, plural=True), u'הראשונים')
        self.assertEqual(num2words(1, ordinal=True, lang='he', gender='f',
                                   definite=True, plural=True), u'הראשונות')

    def test_cardinal_for_float_number(self):
        self.assertEqual(num2words(12.5, lang='he'), u'שתים עשרה נקודה חמש')
        self.assertEqual(num2words(
            12.51, lang='he'), u'שתים עשרה נקודה חמש אחת')
        self.assertEqual(num2words(
            12.53, lang='he'), u'שתים עשרה נקודה חמש שלוש')
        self.assertEqual(num2words(
            12.59, lang='he'), u'שתים עשרה נקודה חמש תשע')
        self.assertEqual(num2words(
            12.5, lang='he', gender='m'), u'שנים עשר נקודה חמש')
        self.assertEqual(num2words(
            12.51, lang='he', gender='m'), u'שנים עשר נקודה חמש אחת')
        self.assertEqual(num2words(
            12.53, lang='he', gender='m'), u'שנים עשר נקודה חמש שלוש')
        self.assertEqual(num2words(
            12.59, lang='he', gender='m'), u'שנים עשר נקודה חמש תשע')
        self.assertEqual(num2words(12.594132, lang='he', gender='m'),
                         u'שנים עשר נקודה חמש תשע ארבע אחת שלוש שתיים')

    def test_cardinal_float_precision(self):
        n = Num2Word_HE()
        self.assertEqual(n.to_cardinal_float("1.23"), 'אחת נקודה שתיים שלוש')
        n.precision = 1
        self.assertEqual(n.to_cardinal_float("1.2"), 'אחת נקודה שתיים')

    def test_error_to_cardinal_float(self):
        n = Num2Word_HE()
        with self.assertRaises(TypeError):
            n.to_cardinal_float("a")

    def test_overflow(self):
        n = Num2Word_HE()
        num2words(n.MAXVAL - 1, lang="he")
        num2words(n.MAXVAL - 1, ordinal=True, lang="he")

        with self.assertRaises(OverflowError):
            num2words(n.MAXVAL, lang="he")

        with self.assertRaises(OverflowError):
            num2words(n.MAXVAL, lang="he", ordinal=True)

        with self.assertRaises(OverflowError):
            int2word(n.MAXVAL)



# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from __future__ import unicode_literals

from unittest import TestCase

from num2words import num2words


class Num2WordsPLTest(TestCase):
    def test_cardinal(self):
        self.assertEqual(num2words(90, lang='pl'), "dziewięćdziesiąt")
        self.assertEqual(num2words(100, lang='pl'), "sto")
        self.assertEqual(num2words(101, lang='pl'), "sto jeden")
        self.assertEqual(num2words(110, lang='pl'), "sto dziesięć")
        self.assertEqual(num2words(115, lang='pl'), "sto piętnaście")
        self.assertEqual(num2words(123, lang='pl'), "sto dwadzieścia trzy")
        self.assertEqual(num2words(400, lang='pl'), "czterysta")
        self.assertEqual(num2words(1000, lang='pl'), "tysiąc")
        self.assertEqual(num2words(1001, lang='pl'), "tysiąc jeden")
        self.assertEqual(num2words(2012, lang='pl'), "dwa tysiące dwanaście")
        self.assertEqual(
            num2words(10.02, lang='pl'),
            "dziesięć przecinek zero dwa"
        )
        self.assertEqual(
            num2words(15.007, lang='pl'),
            "piętnaście przecinek zero zero siedem"
        )
        self.assertEqual(
            num2words(12519.85, lang='pl'),
            "dwanaście tysięcy pięćset dziewiętnaście przecinek "
            "osiemdziesiąt pięć"
        )
        self.assertEqual(
            num2words(123.50, lang='pl'),
            "sto dwadzieścia trzy przecinek pięć"
        )
        self.assertEqual(
            num2words(1234567890, lang='pl'),
            "miliard dwieście trzydzieści cztery miliony pięćset "
            "sześćdziesiąt siedem tysięcy osiemset dziewięćdziesiąt"
        )
        self.assertEqual(
            num2words(10000000001000000100000, lang='pl'),
            "dziesięć tryliardów bilion sto tysięcy"
        )
        self.assertEqual(
            num2words(215461407892039002157189883901676, lang='pl'),
            "dwieście piętnaście kwintylionów czterysta sześćdziesiąt jeden "
            "kwadryliardów czterysta siedem kwadrylionów osiemset "
            "dziewięćdziesiąt dwa tryliardy trzydzieści dziewięć trylionów "
            "dwa biliardy sto pięćdziesiąt siedem bilionów sto osiemdziesiąt "
            "dziewięć miliardów osiemset osiemdziesiąt trzy miliony "
            "dziewięćset jeden tysięcy sześćset siedemdziesiąt sześć"
        )
        self.assertEqual(
            num2words(719094234693663034822824384220291, lang='pl'),
            "siedemset dziewiętnaście kwintylionów dziewięćdziesiąt cztery "
            "kwadryliardy dwieście trzydzieści cztery kwadryliony sześćset "
            "dziewięćdziesiąt trzy tryliardy sześćset sześćdziesiąt trzy "
            "tryliony trzydzieści cztery biliardy osiemset dwadzieścia dwa "
            "biliony osiemset dwadzieścia cztery miliardy trzysta "
            "osiemdziesiąt cztery miliony dwieście dwadzieścia "
            "tysięcy dwieście dziewięćdziesiąt jeden"
        )
        self.assertEqual(
            num2words(
                963301000001918264129471001047146102 * 10**30 + 1007,
                lang='pl'
            ),
            "dziewięćset sześćdziesiąt trzy decyliardy trzysta jeden "
            "decylionów nonylion dziewięćset osiemnaście oktyliardów dwieście "
            "sześćdziesiąt cztery oktyliony sto dwadzieścia dziewięć "
            "septyliardów czterysta siedemdziesiąt jeden septylionów "
            "sekstyliard czterdzieści siedem sekstylionów sto czterdzieści "
            "sześć kwintyliardów sto dwa kwintyliony tysiąc siedem"
        )

    def test_to_ordinal(self):
        self.assertEqual(num2words(100, lang='pl', to='ordinal'), "setny")
        self.assertEqual(
            num2words(101, lang='pl', to='ordinal'), "sto pierwszy")
        self.assertEqual(num2words(120, lang='pl', to='ordinal'),
                         "sto dwudziesty")
        self.assertEqual(num2words(20, lang='pl', to='ordinal'), "dwudziesty")
        self.assertEqual(num2words(121, lang='pl', to='ordinal'),
                         "sto dwudziesty pierwszy")
        self.assertEqual(
            num2words(115, lang='pl', to='ordinal'), "sto piętnasty")
        self.assertEqual(
            num2words(25, lang='pl', to='ordinal'), "dwudziesty piąty")
        self.assertEqual(num2words(1021, lang='pl', to='ordinal'),
                         "tysiąc dwudziesty pierwszy")
        self.assertEqual(
            num2words(120, lang='pl', to='ordinal'), "sto dwudziesty")
        self.assertEqual(num2words(1000021, lang='pl',
                                   to='ordinal'), "milion dwudziesty pierwszy")
        self.assertEqual(num2words(1000, lang='pl', to='ordinal'), "tysięczny")
        self.assertEqual(num2words(10000, lang='pl',
                                   to='ordinal'), "dziesięciotysięczny")
        self.assertEqual(num2words(100000000, lang='pl',
                                   to='ordinal'), "stumilionowy")
        self.assertEqual(num2words(1002000, lang='pl',
                                   to='ordinal'), "milion dwutysięczny")
        self.assertEqual(num2words(1001000, lang='pl',
                                   to='ordinal'), "milion tysięczny")
        self.assertEqual(num2words(1000000, lang='pl',
                                   to='ordinal'), "milionowy")

    def test_to_ordinal_error(self):
        with self.assertRaises(NotImplementedError):
            num2words(1.5, lang='pl', to='ordinal')

    def test_currency(self):
        self.assertEqual(
            num2words(1.0, lang='pl', to='currency', currency='EUR'),
            "jeden euro, zero centów")
        self.assertEqual(
            num2words(1.0, lang='pl', to='currency', currency='PLN'),
            "jeden złoty, zero groszy")
        self.assertEqual(
            num2words(1234.56, lang='pl', to='currency', currency='EUR'),
            "tysiąc dwieście trzydzieści cztery euro, pięćdziesiąt sześć "
            "centów"
        )
        self.assertEqual(
            num2words(1234.56, lang='pl', to='currency', currency='PLN'),
            "tysiąc dwieście trzydzieści cztery złote, pięćdziesiąt sześć "
            "groszy"
        )
        self.assertEqual(
            num2words(10111, lang='pl', to='currency', currency='EUR',
                      separator=' i'),
            "sto jeden euro i jedenaście centów"
        )
        self.assertEqual(
            num2words(10121, lang='pl', to='currency', currency='PLN',
                      separator=' i'),
            "sto jeden złotych i dwadzieścia jeden groszy"
        )
        self.assertEqual(
            num2words(-1251985, lang='pl', to='currency', cents=False),
            "minus dwanaście tysięcy pięćset dziewiętnaście euro, 85 centów"
        )
        self.assertEqual(
            num2words(123.50, lang='pl', to='currency', currency='PLN',
                      separator=' i'),
            "sto dwadzieścia trzy złote i pięćdziesiąt groszy"
        )
        self.assertEqual(
            num2words(1950, lang='pl', to='currency', cents=False),
            "dziewiętnaście euro, 50 centów"
        )



# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from __future__ import unicode_literals

from decimal import Decimal
from unittest import TestCase

from num2words.base import Num2Word_Base


class Num2WordBaseTest(TestCase):
    @classmethod
    def setUpClass(cls):
        super(Num2WordBaseTest, cls).setUpClass()
        cls.base = Num2Word_Base()

    def test_to_currency_not_implemented(self):
        with self.assertRaises(NotImplementedError):
            self.base.to_currency(Decimal('1.00'), currency='EUR')

    def test_error_to_cardinal_float(self):
        from num2words.base import Num2Word_Base
        self.base = Num2Word_Base()
        with self.assertRaises(TypeError):
            self.base.to_cardinal_float("a")

    def test_error_merge(self):
        from num2words.base import Num2Word_Base
        self.base = Num2Word_Base()
        with self.assertRaises(NotImplementedError):
            self.base.merge(2, 3)

    def test_is_title(self):
        from num2words.base import Num2Word_Base
        self.base = Num2Word_Base()
        self.assertEqual(
            self.base.title("one"),
            "one"
            )
        self.base.is_title = True
        self.assertEqual(
            self.base.title("one"),
            "One"
            )
        self.base.exclude_title.append('one')
        self.assertEqual(
            self.base.title("one"),
            "one"
            )



# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from __future__ import division, print_function, unicode_literals

from . import lang_EU

ZERO = 'nulla'


class Num2Word_HU(lang_EU.Num2Word_EU):
    GIGA_SUFFIX = "illiárd"
    MEGA_SUFFIX = "illió"

    def setup(self):
        super(Num2Word_HU, self).setup()

        self.negword = "mínusz "
        self.pointword = "egész"

        self.mid_numwords = [(1000, "ezer"), (100, "száz"), (90, "kilencven"),
                             (80, "nyolcvan"), (70, "hetven"), (60, "hatvan"),
                             (50, "ötven"), (40, "negyven"), (30, "harminc")]

        low_numwords = ["kilenc", "nyolc", "hét", "hat", "öt", "négy", "három",
                        "kettő", "egy"]
        self.low_numwords = (['tizen' + w for w in low_numwords]
                             + ['tíz']
                             + low_numwords)
        self.low_numwords = (['huszon' + w for w in low_numwords]
                             + ['húsz']
                             + self.low_numwords
                             + [ZERO])

        self.partial_ords = {
            'nulla': 'nullad',
            'egy': 'egyed',
            'kettő': 'ketted',
            'három': 'harmad',
            'négy': 'negyed',
            'öt': 'ötöd',
            'hat': 'hatod',
            'hét': 'heted',
            'nyolc': 'nyolcad',
            'kilenc': 'kilenced',
            'tíz': 'tized',
            'húsz': 'huszad',
            'harminc': 'harmincad',
            'negyven': 'negyvened',
            'ötven': 'ötvened',
            'hatvan': 'hatvanad',
            'hetven': 'hetvened',
            'nyolcvan': 'nyolcvanad',
            'kilencven': 'kilencvened',
            'száz': 'század',
            'ezer': 'ezred',
            'illió': 'milliomod',
            'illiárd': 'milliárdod'
        }

    def to_cardinal(self, value, zero=ZERO):
        if int(value) != value:
            return self.to_cardinal_float(value)
        elif value < 0:
            out = self.negword + self.to_cardinal(-value)
        elif value == 0:
            out = zero
        elif zero == '' and value == 2:
            out = 'két'
        elif value < 30:
            out = self.cards[value]
        elif value < 100:
            out = self.tens_to_cardinal(value)
        elif value < 1000:
            out = self.hundreds_to_cardinal(value)
        elif value < 10**6:
            out = self.thousands_to_cardinal(value)
        else:
            out = self.big_number_to_cardinal(value)
        return out

    def tens_to_cardinal(self, value):
        try:
            return self.cards[value]
        except KeyError:
            return self.cards[value // 10 * 10] + self.to_cardinal(value % 10)

    def hundreds_to_cardinal(self, value):
        hundreds = value // 100
        prefix = "száz"
        if hundreds != 1:
            prefix = self.to_cardinal(hundreds, zero="") + prefix
        postfix = self.to_cardinal(value % 100, zero="")
        return prefix + postfix

    def thousands_to_cardinal(self, value):
        thousands = value // 1000
        prefix = "ezer"
        if thousands != 1:
            prefix = self.to_cardinal(thousands, zero="") + prefix
        postfix = self.to_cardinal(value % 1000, zero="")
        return prefix + ('' if value <= 2000 or not postfix else '-') + postfix

    def big_number_to_cardinal(self, value):
        digits = len(str(value))
        digits = digits if digits % 3 != 0 else digits - 2
        exp = 10 ** (digits // 3 * 3)
        rest = self.to_cardinal(value % exp, '')
        return (self.to_cardinal(value // exp, '') + self.cards[exp]
                + ('-' + rest if rest else ''))

    def to_ordinal(self, value):
        if value < 0:
            return self.negword + self.to_ordinal(-value)
        if value == 1:
            return 'első'
        elif value == 2:
            return 'második'
        else:
            out = self.to_cardinal(value)
            for card_word, ord_word in self.partial_ords.items():
                if out[-len(card_word):] == card_word:
                    out = out[:-len(card_word)] + ord_word
                    break
        return out + 'ik'

    def to_ordinal_num(self, value):
        self.verify_ordinal(value)
        return str(value) + '.'

    def to_year(self, val, suffix=None, longval=True):
        # suffix is prefix here
        prefix = ''
        if val < 0 or suffix is not None:
            val = abs(val)
            prefix = (suffix + ' ' if suffix is not None else 'i. e. ')
        return prefix + self.to_cardinal(val)

    def to_currency(self, val, currency='HUF', cents=True, separator=',',
                    adjective=False):
        return super(Num2Word_HU, self).to_currency(
            val, currency, cents, separator, adjective)

    def to_cardinal_float(self, value):
        if abs(value) != value:
            return self.negword + self.to_cardinal_float(-value)
        left, right = str(value).split('.')
        return (self.to_cardinal(int(left))
                + ' egész '
                + self.to_cardinal(int(right))
                + ' ' + self.partial_ords[self.cards[10 ** len(right)]])



# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.
# Copyright (c) 2020, Hamidreza Kalbasi.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from unittest import TestCase

from num2words import num2words


class Num2WordsFATest(TestCase):
    def test_and_join_199(self):
        self.assertEqual(num2words(199, lang='fa'), "صد و نود و نه")

    def test_ordinal(self):
        self.assertEqual(
            num2words(0, lang='fa', to='ordinal'),
            'صفرم'
        )
        self.assertEqual(
            num2words(1, lang='fa', to='ordinal'),
            'یکم'
        )
        self.assertEqual(
            num2words(13, lang='fa', to='ordinal'),
            'سیزدهم'
        )
        self.assertEqual(
            num2words(23, lang='fa', to='ordinal'),
            'بیست و سوم'
        )
        self.assertEqual(
            num2words(12, lang='fa', to='ordinal'),
            'دوازدهم'
        )
        self.assertEqual(
            num2words(113, lang='fa', to='ordinal'),
            'صد و سیزدهم'
        )
        self.assertEqual(
            num2words(103, lang='fa', to='ordinal'),
            'صد و سوم'
        )

    def test_cardinal(self):
        self.assertEqual(num2words(130000, lang='fa'), "صد و سی هزار")
        self.assertEqual(num2words(242, lang='fa'), "دویست و چهل و دو")
        self.assertEqual(num2words(800, lang='fa'), "هشتصد")
        self.assertEqual(num2words(-203, lang='fa'), "منفی دویست و سه")
        self.assertEqual(
            num2words(1234567890, lang='fa'),
            "یک میلیارد و دویست و سی و چهار میلیون و"
            " پانصد و شصت و هفت هزار و هشتصد و نود"
        )

    def test_year(self):
        self.assertEqual(num2words(1398, lang='fa', to='year'),
                         "هزار و سیصد و نود و هشت")
        self.assertEqual(num2words(1399, lang='fa', to='year'),
                         "هزار و سیصد و نود و نه")
        self.assertEqual(
            num2words(1400, lang='fa', to='year'), "هزار و چهارصد")

    def test_currency(self):
        self.assertEqual(
            num2words(1000, lang='fa', to='currency'), 'هزار تومان')
        self.assertEqual(
            num2words(1500000, lang='fa', to='currency'),
            'یک میلیون و پانصد هزار تومان'
        )

    def test_ordinal_num(self):
        self.assertEqual(num2words(10, lang='fa', to='ordinal_num'), '10م')
        self.assertEqual(num2words(21, lang='fa', to='ordinal_num'), '21م')
        self.assertEqual(num2words(102, lang='fa', to='ordinal_num'), '102م')
        self.assertEqual(num2words(73, lang='fa', to='ordinal_num'), '73م')

    def test_cardinal_for_float_number(self):
        self.assertEqual(num2words(12.5, lang='fa'), "دوازده و نیم")
        self.assertEqual(num2words(0.75, lang='fa'), "هفتاد و پنج صدم")
        self.assertEqual(num2words(12.51, lang='fa'),
                         "دوازده و پنجاه و یک صدم")
        self.assertEqual(num2words(12.53, lang='fa'),
                         "دوازده و پنجاه و سه صدم")
        self.assertEqual(num2words(12.59, lang='fa'),
                         "دوازده و پنجاه و نه صدم")
        self.assertEqual(num2words(0.000001, lang='fa'), "یک میلیونیم")

    def test_overflow(self):
        with self.assertRaises(OverflowError):
            num2words("1000000000000000000000000000000000000000000000000000000"
                      "0000000000000000000000000000000000000000000000000000000"
                      "0000000000000000000000000000000000000000000000000000000"
                      "0000000000000000000000000000000000000000000000000000000"
                      "0000000000000000000000000000000000000000000000000000000"
                      "00000000000000000000000000000000")



# coding: utf-8
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from __future__ import unicode_literals

from unittest import TestCase

from num2words import num2words


class Num2WordsNOTest(TestCase):
    def test_cardinal(self):
        self.assertEqual(num2words(0, to="cardinal", lang="no"), "null")
        self.assertEqual(num2words(1, to="cardinal", lang="no"), "en")
        self.assertEqual(num2words(3, to="cardinal", lang="no"), "tre")
        self.assertEqual(num2words(5, to="cardinal", lang="no"), "fem")
        self.assertEqual(num2words(18, to="cardinal", lang="no"), "atten")
        self.assertEqual(num2words(45, to="cardinal", lang="no"), "førtifem")
        self.assertEqual(num2words(92, to="cardinal", lang="no"), "nittito")
        self.assertEqual(num2words(1345, to="cardinal", lang="no"),
                         "en tusen tre hundre og førtifem")
        self.assertEqual(num2words(4435, to="cardinal", lang="no"),
                         "fire tusen fire hundre og trettifem")
        self.assertEqual(num2words(1004435, to="cardinal", lang="no"),
                         "en million fire tusen fire hundre og trettifem")
        self.assertEqual(num2words(4335000, to="cardinal", lang="no"),
                         "fire million tre hundre og trettifem tusen")
        self.assertEqual(num2words(14004535, to="cardinal", lang="no"),
                         "fjorten million fire tusen fem hundre og trettifem")
        self.assertEqual(num2words(1.5, to="cardinal", lang="no"),
                         "en komma fem")

    def test_ordinal(self):
        self.assertEqual(num2words(1, to="ordinal", lang="no"), "første")
        self.assertEqual(num2words(5, to="ordinal", lang="no"), "femte")
        self.assertEqual(num2words(10, to="ordinal", lang="no"), "tiende")
        self.assertEqual(num2words(14, to="ordinal", lang="no"), "fjortende")
        self.assertEqual(num2words(30, to="ordinal", lang="no"), "trettiende")
        self.assertEqual(num2words(32, to="ordinal", lang="no"), "trettiandre")
        self.assertEqual(num2words(100, to="ordinal", lang="no"),
                         "en hundrede")
        self.assertEqual(num2words(1000, to="ordinal", lang="no"),
                         "en tusende")
        self.assertEqual(num2words(1435, to="ordinal", lang="no"),
                         "en tusen fire hundre og trettifemte")
        self.assertEqual(num2words(1000000, to="ordinal", lang="no"),
                         "en millionte")

    def test_ordinal_num(self):
        self.assertEqual(num2words(1, to="ordinal_num", lang="no"), "1.")
        self.assertEqual(num2words(5, to="ordinal_num", lang="no"), "5.")
        self.assertEqual(num2words(10, to="ordinal_num", lang="no"), "10.")
        self.assertEqual(num2words(14, to="ordinal_num", lang="no"), "14.")
        self.assertEqual(num2words(32, to="ordinal_num", lang="no"), "32.")

    def test_year(self):
        self.assertEqual(num2words(1835, to="year", lang="no"),
                         "atten hundre og trettifem")
        self.assertEqual(num2words(2015, to="year", lang="no"),
                         "to tusen og femten")

    def test_currency(self):
        self.assertEqual(num2words(1.00, to="currency", lang="no"), "en krone")
        self.assertEqual(num2words(2.00, to="currency", lang="no"),
                         "to kroner")
        self.assertEqual(num2words(2.50, to="currency", lang="no"),
                         "to kroner og femti øre")
        self.assertEqual(num2words(135.00, to="currency", lang="no"),
                         "en hundre og trettifem kroner")
        self.assertEqual(num2words(135.59, to="currency", lang="no"),
                         "en hundre og trettifem kroner og femtini øre")



# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from __future__ import unicode_literals

from unittest import TestCase

from num2words import num2words
from num2words.lang_TH import Num2Word_TH


class TestNumWord(TestCase):

    def test_0(self):
        self.assertEqual(num2words(0, lang='th'), "ศูนย์")

    def test_end_with_1(self):
        self.assertEqual(num2words(21, lang='th'), "ยี่สิบเอ็ด")
        self.assertEqual(num2words(11, lang='th'), "สิบเอ็ด")
        self.assertEqual(num2words(101, lang='th'), "หนึ่งร้อยเอ็ด")
        self.assertEqual(num2words(1201, lang='th'), "หนึ่งพันสองร้อยเอ็ด")

    def test_start_20(self):
        self.assertEqual(num2words(22, lang='th'), "ยี่สิบสอง")
        self.assertEqual(num2words(27, lang='th'), "ยี่สิบเจ็ด")

    def test_start_10(self):
        self.assertEqual(num2words(10, lang='th'), "สิบ")
        self.assertEqual(num2words(18, lang='th'), "สิบแปด")

    def test_1_to_9(self):
        self.assertEqual(num2words(1, lang='th'), "หนึ่ง")
        self.assertEqual(num2words(5, lang='th'), "ห้า")
        self.assertEqual(num2words(9, lang='th'), "เก้า")

    def test_31_to_99(self):
        self.assertEqual(num2words(31, lang='th'), "สามสิบเอ็ด")
        self.assertEqual(num2words(48, lang='th'), "สี่สิบแปด")
        self.assertEqual(num2words(76, lang='th'), "เจ็ดสิบหก")

    def test_100_to_999(self):
        self.assertEqual(num2words(100, lang='th'), "หนึ่งร้อย")
        self.assertEqual(num2words(123, lang='th'), "หนึ่งร้อยยี่สิบสาม")
        self.assertEqual(num2words(456, lang='th'), "สี่ร้อยห้าสิบหก")
        self.assertEqual(num2words(721, lang='th'), "เจ็ดร้อยยี่สิบเอ็ด")

    def test_1000_to_9999(self):
        self.assertEqual(num2words(1000, lang='th'), "หนึ่งพัน")
        self.assertEqual(
            num2words(2175, lang='th'), "สองพันหนึ่งร้อยเจ็ดสิบห้า"
        )
        self.assertEqual(num2words(4582, lang='th'), "สี่พันห้าร้อยแปดสิบสอง")
        self.assertEqual(num2words(9346, lang='th'), "เก้าพันสามร้อยสี่สิบหก")

    def test_10000_to_99999(self):
        self.assertEqual(
            num2words(11111, lang='th'), "หนึ่งหมื่นหนึ่งพันหนึ่งร้อยสิบเอ็ด"
        )
        self.assertEqual(
            num2words(22222, lang='th'), "สองหมื่นสองพันสองร้อยยี่สิบสอง"
        )
        self.assertEqual(
            num2words(84573, lang='th'), "แปดหมื่นสี่พันห้าร้อยเจ็ดสิบสาม"
        )

    def test_100000_to_999999(self):
        self.assertEqual(
            num2words(153247, lang='th'),
            "หนึ่งแสนห้าหมื่นสามพันสองร้อยสี่สิบเจ็ด"
        )
        self.assertEqual(
            num2words(562442, lang='th'),
            "ห้าแสนหกหมื่นสองพันสี่ร้อยสี่สิบสอง"
        )
        self.assertEqual(
            num2words(999999, lang='th'),
            "เก้าแสนเก้าหมื่นเก้าพันเก้าร้อยเก้าสิบเก้า"
        )

    def test_more_than_million(self):
        self.assertEqual(
            num2words(1000000, lang='th'),
            "หนึ่งล้าน"
        )
        self.assertEqual(
            num2words(1000001, lang='th'),
            "หนึ่งล้านเอ็ด"
        )
        self.assertEqual(
            num2words(42478941, lang='th'),
            "สี่สิบสองล้านสี่แสนเจ็ดหมื่นแปดพันเก้าร้อยสี่สิบเอ็ด"
        )
        self.assertEqual(
            num2words(712696969, lang='th'),
            "เจ็ดร้อยสิบสองล้านหกแสนเก้าหมื่นหกพันเก้าร้อยหกสิบเก้า"
        )
        self.assertEqual(
            num2words(1000000000000000001, lang='th'),
            "หนึ่งล้านล้านล้านเอ็ด"
        )

    def test_decimal(self):
        self.assertEqual(
            num2words(0.0, lang='th'), "ศูนย์"
        )
        self.assertEqual(
            num2words(0.0038, lang='th'), "ศูนย์จุดศูนย์ศูนย์สามแปด"
        )
        self.assertEqual(
            num2words(0.01, lang='th'), "ศูนย์จุดศูนย์หนึ่ง"
        )
        self.assertEqual(
            num2words(1.123, lang='th'), "หนึ่งจุดหนึ่งสองสาม"
        )
        self.assertEqual(
            num2words(35.37, lang='th'), "สามสิบห้าจุดสามเจ็ด"
        )
        self.assertEqual(
            num2words(1000000.01, lang='th'), "หนึ่งล้านจุดศูนย์หนึ่ง"
        )

    def test_currency(self):
        self.assertEqual(
            num2words(100, lang='th', to='currency', currency='THB'),
            "หนึ่งร้อยบาทถ้วน"
        )
        self.assertEqual(
            num2words(100, lang='th', to='currency', currency='USD'),
            "หนึ่งร้อยดอลลาร์"
        )
        self.assertEqual(
            num2words(100, lang='th', to='currency', currency='EUR'),
            "หนึ่งร้อยยูโร"
        )

    def test_currency_decimal(self):
        self.assertEqual(
            num2words(0.00, lang='th', to='currency'), "ศูนย์บาทถ้วน"
        )
        self.assertEqual(
            num2words(0.05, lang='th', to='currency'), "ห้าสตางค์"
        )
        self.assertEqual(
            num2words(0.50, lang='th', to='currency'), "ห้าสิบสตางค์"
        )
        self.assertEqual(
            num2words(0.99, lang='th', to='currency'), "เก้าสิบเก้าสตางค์"
        )
        self.assertEqual(
            num2words(100.00, lang='th', to='currency'), "หนึ่งร้อยบาทถ้วน"
        )
        self.assertEqual(
            num2words(100.23, lang='th', to='currency', currency='USD'),
            "หนึ่งร้อยดอลลาร์ยี่สิบสามเซนต์"
        )
        self.assertEqual(
            num2words(100.24, lang='th', to='currency', currency='EUR'),
            "หนึ่งร้อยยูโรยี่สิบสี่เซนต์"
        )

    def test_negative(self):
        self.assertEqual(num2words(-10, lang='th'), "ติดลบสิบ")
        self.assertEqual(num2words(-10.50, lang='th'), "ติดลบสิบจุดห้า")
        self.assertEqual(
            num2words(-100.00, lang='th', to='currency'),
            "ติดลบหนึ่งร้อยบาทถ้วน"
        )

    def test_round_2_decimal(self):
        n2wTH = Num2Word_TH()
        self.assertEqual(n2wTH.round_2_decimal(0.004), ('0.00', False))
        self.assertEqual(n2wTH.round_2_decimal(0.005), ('0.01', False))
        self.assertEqual(n2wTH.round_2_decimal(0.006), ('0.01', False))
        self.assertEqual(n2wTH.round_2_decimal(0.0005),
                         ('0.00', False))
        self.assertEqual(n2wTH.round_2_decimal(0.984), ('0.98', False))
        self.assertEqual(n2wTH.round_2_decimal(0.989), ('0.99', False))
        self.assertEqual(n2wTH.round_2_decimal(0.994), ('0.99', False))
        self.assertEqual(n2wTH.round_2_decimal(0.999), ('1.00', False))
        self.assertEqual(n2wTH.round_2_decimal(-0.994), ('0.99', True))
        self.assertEqual(n2wTH.round_2_decimal(-0.999), ('1.00', True))
        # self.assertEqual(n2wTH.round_2_decimal(0.985), ('0.99', False))
        # Expect 0.99 get 0.98
        # self.assertEqual(n2wTH.round_2_decimal(0.995), ('1.00', False))
        # Expect 1.00 get 0.99

    def test_split_six(self):
        n2wTH = Num2Word_TH()
        self.assertEqual(n2wTH.split_six(str(123456789)),
                         ['987654', '321'])
        self.assertEqual(n2wTH.split_six(str(12345)),
                         ['54321'])
        self.assertEqual(n2wTH.split_six(str(1234567)),
                         ['765432', '1'])



# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from __future__ import unicode_literals

from .base import Num2Word_Base

GENERIC_DOLLARS = ('dollar', 'dollars')
GENERIC_CENTS = ('cent', 'cents')


class Num2Word_EU(Num2Word_Base):
    CURRENCY_FORMS = {
        'AUD': (GENERIC_DOLLARS, GENERIC_CENTS),
        'BYN': (('rouble', 'roubles'), ('kopek', 'kopeks')),
        'CAD': (GENERIC_DOLLARS, GENERIC_CENTS),
        # repalced by EUR
        'EEK': (('kroon', 'kroons'), ('sent', 'senti')),
        'EUR': (('euro', 'euro'), GENERIC_CENTS),
        'GBP': (('pound sterling', 'pounds sterling'), ('penny', 'pence')),
        # replaced by EUR
        'LTL': (('litas', 'litas'), GENERIC_CENTS),
        # replaced by EUR
        'LVL': (('lat', 'lats'), ('santim', 'santims')),
        'USD': (GENERIC_DOLLARS, GENERIC_CENTS),
        'RUB': (('rouble', 'roubles'), ('kopek', 'kopeks')),
        'SEK': (('krona', 'kronor'), ('öre', 'öre')),
        'NOK': (('krone', 'kroner'), ('øre', 'øre')),
        'PLN': (('zloty', 'zlotys', 'zlotu'), ('grosz', 'groszy')),
        'MXN': (('peso', 'pesos'), GENERIC_CENTS),
        'RON': (('leu', 'lei', 'de lei'), ('ban', 'bani', 'de bani')),
        'INR': (('rupee', 'rupees'), ('paisa', 'paise')),
        'HUF': (('forint', 'forint'), ('fillér', 'fillér')),
        'ISK': (('króna', 'krónur'), ('aur', 'aurar')),
        'UZS': (('sum', 'sums'), ('tiyin', 'tiyins')),
        'SAR': (('saudi riyal', 'saudi riyals'), ('halalah', 'halalas'))

    }

    CURRENCY_ADJECTIVES = {
        'AUD': 'Australian',
        'BYN': 'Belarussian',
        'CAD': 'Canadian',
        'EEK': 'Estonian',
        'USD': 'US',
        'RUB': 'Russian',
        'NOK': 'Norwegian',
        'MXN': 'Mexican',
        'RON': 'Romanian',
        'INR': 'Indian',
        'HUF': 'Hungarian',
        'ISK': 'íslenskar',
        'UZS': 'Uzbekistan',
        'SAR': 'Saudi'
    }

    GIGA_SUFFIX = "illiard"
    MEGA_SUFFIX = "illion"

    def set_high_numwords(self, high):
        cap = 3 + 6 * len(high)

        for word, n in zip(high, range(cap, 3, -6)):
            if self.GIGA_SUFFIX:
                self.cards[10 ** n] = word + self.GIGA_SUFFIX

            if self.MEGA_SUFFIX:
                self.cards[10 ** (n - 3)] = word + self.MEGA_SUFFIX

    def gen_high_numwords(self, units, tens, lows):
        out = [u + t for t in tens for u in units]
        out.reverse()
        return out + lows

    def pluralize(self, n, forms):
        form = 0 if n == 1 else 1
        return forms[form]

    def setup(self):
        lows = ["non", "oct", "sept", "sext", "quint", "quadr", "tr", "b", "m"]
        units = ["", "un", "duo", "tre", "quattuor", "quin", "sex", "sept",
                 "octo", "novem"]
        tens = ["dec", "vigint", "trigint", "quadragint", "quinquagint",
                "sexagint", "septuagint", "octogint", "nonagint"]
        self.high_numwords = ["cent"] + self.gen_high_numwords(units, tens,
                                                               lows)



# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from __future__ import unicode_literals

from unittest import TestCase

from num2words import num2words


class Num2WordsTGTest(TestCase):
    def test_cardinal(self):
        with self.assertRaises(OverflowError):
            num2words(1000000000000000000000000, lang="tg")
        self.assertEqual(num2words(100, lang="tg"), "сад")
        self.assertEqual(num2words(100000, lang="tg"), "сад ҳазор")
        self.assertEqual(num2words(101, lang="tg"), "яксаду як")
        self.assertEqual(num2words(110, lang="tg"), "яксаду даҳ")
        self.assertEqual(num2words(115, lang="tg"), "яксаду понздаҳ")
        self.assertEqual(num2words(123, lang="tg"), "яксаду бисту се")
        self.assertEqual(num2words(1000, lang="tg"), "як ҳазор")
        self.assertEqual(num2words(1001, lang="tg"), "як ҳазору як")
        self.assertEqual(num2words(2012, lang="tg"), "ду ҳазору дувоздаҳ")
        self.assertEqual(
            num2words(12519.85, lang="tg"),
            "дувоздаҳ ҳазору панҷсаду нуздаҳ нуқта ҳашт панҷ",
        )

        self.assertEqual(
            num2words(1234567890, lang="tg"),
            "як миллиарду дусаду сию чор миллиону панҷсаду шасту ҳафт ҳазору "
            "ҳаштсаду навад",
        )
        self.assertEqual(num2words(1000000, lang="tg"), "як миллион")
        self.assertEqual(num2words(1000000000, lang="tg"), "як миллиард")
        self.assertEqual(num2words(1000000000000, lang="tg"), "як триллион")
        self.assertEqual(num2words(5, lang="tg"), "панҷ")
        self.assertEqual(num2words(-1, lang="tg"), "минус як")
        self.assertEqual(num2words(-15, lang="tg"), "минус понздаҳ")
        self.assertEqual(num2words(-100, lang="tg"), "минус сад")

    def test_to_ordinal(self):
        self.assertEqual(num2words(1, lang="tg", to="ordinal"), "якум")
        self.assertEqual(num2words(2, lang="tg", to="ordinal"), "дуюм")
        self.assertEqual(num2words(3, lang="tg", to="ordinal"), "сеюм")
        self.assertEqual(num2words(30, lang="tg", to="ordinal"), "сиюм")

        self.assertEqual(num2words(13, lang="tg", to="ordinal"), "сенздаҳум")
        self.assertEqual(num2words(20, lang="tg", to="ordinal"), "бистум")
        self.assertEqual(num2words(23, lang="tg", to="ordinal"), "бисту сеюм")
        self.assertEqual(num2words(100, lang="tg", to="ordinal"), "садум")
        self.assertEqual(
            num2words(136, lang="tg", to="ordinal"), "яксаду сию шашум"
        )
        self.assertEqual(num2words(500, lang="tg", to="ordinal"), "панҷсадум")
        self.assertEqual(
            num2words(1000, lang="tg", to="ordinal"), "як ҳазорум"
        )
        self.assertEqual(
            num2words(1001, lang="tg", to="ordinal"), "як ҳазору якум"
        )
        self.assertEqual(
            num2words(2000, lang="tg", to="ordinal"), "ду ҳазорум"
        )
        self.assertEqual(
            num2words(1000000, lang="tg", to="ordinal"), "як миллионум"
        )
        self.assertEqual(
            num2words(1000000000, lang="tg", to="ordinal"), "як миллиардум"
        )

    def test_to_currency(self):
        self.assertEqual(
            num2words(1.0, lang="tg", to="currency", currency="EUR"),
            "як евро, сифр сент",
        )
        self.assertEqual(
            num2words(1.0, lang="tg", to="currency", currency="TJS"),
            "як сомонӣ, сифр дирам",
        )
        self.assertEqual(
            num2words(1234.56, lang="tg", to="currency", currency="TJS"),
            "як ҳазору дусаду сию чор сомонӣ, панҷову шаш дирам",
        )
        self.assertEqual(
            num2words(1234.56, lang="tg", to="currency", currency="RUB"),
            "як ҳазору дусаду сию чор рубл, панҷову шаш копейк",
        )
        self.assertEqual(
            num2words(
                12519.85, lang="tg", to="currency", currency="TJS", cents=False
            ),
            "дувоздаҳ ҳазору панҷсаду нуздаҳ сомонӣ, 85 дирам",
        )
        self.assertEqual(
            num2words("1230.56", lang="tg", to="currency", currency="USD"),
            "як ҳазору дусаду си доллар, панҷову шаш сент",
        )

    def test_to_ordinal_num(self):
        self.assertEqual(
            num2words("100", lang="tg", to="ordinal_num"),
            "100ум",
        )



# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA
from __future__ import unicode_literals

from unittest import TestCase

from num2words import num2words

TEST_CASES_CARDINAL = (
    (70, 'septante'),
    (79, 'septante-neuf'),
    (89, 'quatre-vingt-neuf'),
    (95, 'nonante-cinq'),
    (729, 'sept cents vingt-neuf'),
    (894, 'huit cents nonante-quatre'),
    (999, 'neuf cents nonante-neuf'),
    (7232, 'sept mille deux cents trente-deux'),
    (8569, 'huit mille cinq cents soixante-neuf'),
    (9539, 'neuf mille cinq cents trente-neuf'),
    (1000000, 'un millions'),
    (1000001, 'un millions un'),
    (4000000, 'quatre millions'),
    (10000000000000, 'dix billions'),
    (100000000000000, 'cent billions'),
    (1000000000000000000, 'un trillions'),
    (1000000000000000000000, 'un trilliards'),
    (10000000000000000000000000, 'dix quadrillions')
)

TEST_CASES_ORDINAL = (
    (1, 'premier'),
    (8, 'huitième'),
    (12, 'douzième'),
    (14, 'quatorzième'),
    (28, 'vingt-huitième'),
    (100, 'centième'),
    (1000, 'millième'),
    (1000000, 'un millionsième'),
    (1000000000000000, 'un billiardsième'),
    (1000000000000000000, 'un trillionsième')  # over 1e18 is not supported
)

TEST_CASES_TO_CURRENCY_EUR = (
    (1.00, 'un euro et zéro centimes'),
    (2.01, 'deux euros et un centime'),
    (8.10, 'huit euros et dix centimes'),
    (12.26, 'douze euros et vingt-six centimes'),
    (21.29, 'vingt et un euros et vingt-neuf centimes'),
    (81.25, 'quatre-vingt et un euros et vingt-cinq centimes'),
    (100.00, 'cent euros et zéro centimes'),
)

TEST_CASES_TO_CURRENCY_FRF = (
    (1.00, 'un franc et zéro centimes'),
    (2.01, 'deux francs et un centime'),
    (8.10, 'huit francs et dix centimes'),
    (12.27, 'douze francs et vingt-sept centimes'),
    (21.29, 'vingt et un francs et vingt-neuf centimes'),
    (81.25, 'quatre-vingt et un francs et vingt-cinq centimes'),
    (100.00, 'cent francs et zéro centimes'),
)

# Lang to execute current test
LANG = 'fr_BE'


class Num2WordsENTest(TestCase):
    def test_ordinal_special_joins(self):
        self.assertEqual(
            num2words(5, ordinal=True, lang=LANG), "cinquième"
        )
        self.assertEqual(
            num2words(6, ordinal=True, lang=LANG), "sixième"
        )
        self.assertEqual(
            num2words(35, ordinal=True, lang=LANG), "trente-cinquième"
        )
        self.assertEqual(num2words(9, ordinal=True, lang=LANG), "neuvième")
        self.assertEqual(
            num2words(49, ordinal=True, lang=LANG), "quarante-neuvième"
        )
        self.assertEqual(num2words(71, lang=LANG), "septante et un")
        self.assertEqual(num2words(81, lang=LANG), "quatre-vingt et un")
        self.assertEqual(num2words(80, lang=LANG), "quatre-vingt")
        self.assertEqual(
            num2words(880, lang=LANG), "huit cents quatre-vingt")
        self.assertEqual(
            num2words(91, ordinal=True, lang=LANG), "nonante et unième"
        )
        self.assertEqual(num2words(53, lang=LANG), "cinquante-trois")

    def test_number(self):
        for test in TEST_CASES_CARDINAL:
            self.assertEqual(num2words(test[0], lang=LANG), test[1])

    def test_ordinal(self):
        for test in TEST_CASES_ORDINAL:
            self.assertEqual(
                num2words(test[0], lang=LANG, ordinal=True),
                test[1]
            )

    def test_currency_eur(self):
        for test in TEST_CASES_TO_CURRENCY_EUR:
            self.assertEqual(
                num2words(test[0], lang=LANG, to='currency'),
                test[1]
            )

    def test_currency_frf(self):
        for test in TEST_CASES_TO_CURRENCY_FRF:
            self.assertEqual(
                num2words(test[0], lang=LANG, to='currency', currency='FRF'),
                test[1]
            )



# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from unittest import TestCase

from num2words import num2words


class Num2WordsTETest(TestCase):
    def test_numbers(self):
        self.assertEqual(num2words(66, lang="te"), u"అరవై ఆరు")
        self.assertEqual(num2words(1734, lang="te"),
                         u"ఒకటి వేయి ఏడు వందల ముప్పై నాలుగు")
        self.assertEqual(num2words(134, lang="te"),
                         u"ఒకటి వందల ముప్పై నాలుగు")
        self.assertEqual(num2words(54411, lang="te"),
                         u"యాభై నాలుగు వేయి నాలుగు వందల పదకొండు")
        self.assertEqual(num2words(42, lang="te"), u"నలభై రెండు")
        self.assertEqual(num2words(893, lang="te"),
                         u"ఎనిమిది వందల తొంభై మూడు")
        self.assertEqual(
            num2words(1729, lang="te"), u"ఒకటి వేయి ఏడు వందల ఇరవై తొమ్మిది"
        )
        self.assertEqual(num2words(123, lang="te"), u"ఒకటి వందల ఇరవై మూడు")
        self.assertEqual(num2words(32211, lang="te"),
                         u"ముప్పై రెండు వేయి రెండు వందల పదకొండు")

    def test_cardinal_for_float_number(self):
        self.assertEqual(num2words(1.61803, lang="te"),
                         u"ఒకటి బిందువు  ఆరు ఒకటి ఎనిమిది సున్న మూడు")
        self.assertEqual(num2words(34.876, lang="te"),
                         u"ముప్పై నాలుగు బిందువు  ఎనిమిది ఏడు ఆరు")
        self.assertEqual(num2words(3.14, lang="te"),
                         u"మూడు బిందువు  ఒకటి నాలుగు")

    def test_ordinal(self):
        self.assertEqual(num2words(1, lang='te', to='ordinal'), u"ఒకటివ")
        self.assertEqual(num2words(22, lang='te', to='ordinal'),
                         u"ఇరవై రెండువ")
        self.assertEqual(num2words(23, lang='te', to='ordinal'),
                         u"ఇరవై మూడువ")
        self.assertEqual(num2words(12, lang='te', to='ordinal'), u"పన్నెండువ")
        self.assertEqual(num2words(130, lang='te', to='ordinal'),
                         u"ఒకటి వందల ముప్పైవ")
        self.assertEqual(num2words(1003, lang='te', to='ordinal'),
                         u"ఒకటి వేయిల మూడువ")
        self.assertEqual(num2words(4, lang='te', to='ordinal'),
                         u"నాలుగువ")

    def test_ordinal_num(self):
        self.assertEqual(num2words(2, lang="te", to='ordinal_num'), u"2వ")
        self.assertEqual(num2words(3, lang="te", to='ordinal_num'), u"3వ")
        self.assertEqual(num2words(5, lang="te", to='ordinal_num'), u"5వ")
        self.assertEqual(num2words(16, lang="te", to='ordinal_num'), u"16వ")
        self.assertEqual(num2words(113, lang="te", to='ordinal_num'),
                         u"113వ")



# -*- coding: utf-8 -*-
# Copyright (c) 2017, Tufan Kaynak, Framras.  All Rights Reserved.
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from unittest import TestCase

from num2words import num2words


class Num2WordsTRTest(TestCase):
    def test_tr(self):
        # ref https://github.com/savoirfairelinux/num2words/issues/8
        testlang = "tr"
        testcases = [
            {"test": 0, "to": "currency", "expected": u"bedelsiz"},
            {"test": 1.1, "to": "currency", "expected": u"birliraonkuruş"},
            {"test": 2000, "to": "currency", "expected": u"ikibinlira"},
            {"test": 110000, "to": "currency", "expected": u"yüzonbinlira"},
            {"test": 1002000, "to": "currency",
             "expected": u"birmilyonikibinlira"},
            {"test": 1002001, "to": "currency",
             "expected": u"birmilyonikibinbirlira"},
            {"test": 1100000, "to": "currency",
             "expected": u"birmilyonyüzbinlira"},
            {"test": 0, "to": "ordinal", "expected": u"sıfırıncı"},
            {"test": 1, "to": "ordinal", "expected": u"birinci"},
            {"test": 2, "to": "ordinal", "expected": u"ikinci"},
            {"test": 9, "to": "ordinal", "expected": u"dokuzuncu"},
            {"test": 10, "to": "ordinal", "expected": u"onuncu"},
            {"test": 11, "to": "ordinal", "expected": u"onbirinci"},
            {"test": 44, "to": "ordinal", "expected": u"kırkdördüncü"},
            {"test": 100, "to": "ordinal", "expected": u"yüzüncü"},
            {"test": 101, "to": "ordinal", "expected": u"yüzbirinci"},
            {"test": 103, "to": "ordinal", "expected": u"yüzüçüncü"},
            {"test": 110, "to": "ordinal", "expected": u"yüzonuncu"},
            {"test": 111, "to": "ordinal", "expected": u"yüzonbirinci"},
            {"test": 1000, "to": "ordinal", "expected": u"bininci"},
            {"test": 1001, "to": "ordinal", "expected": u"binbirinci"},
            {"test": 1010, "to": "ordinal", "expected": u"binonuncu"},
            {"test": 1011, "to": "ordinal", "expected": u"binonbirinci"},
            {"test": 1100, "to": "ordinal", "expected": u"binyüzüncü"},
            {"test": 1110, "to": "ordinal", "expected": u"binyüzonuncu"},
            {"test": 2341, "to": "ordinal",
             "expected": u"ikibinüçyüzkırkbirinci"},
            {"test": 10000, "to": "ordinal", "expected": u"onbininci"},
            {"test": 10010, "to": "ordinal", "expected": u"onbinonuncu"},
            {"test": 10100, "to": "ordinal", "expected": u"onbinyüzüncü"},
            {"test": 10110, "to": "ordinal", "expected": u"onbinyüzonuncu"},
            {"test": 11000, "to": "ordinal", "expected": u"onbirbininci"},
            {"test": 35000, "to": "ordinal", "expected": u"otuzbeşbininci"},
            {"test": 116331, "to": "ordinal",
             "expected": u"yüzonaltıbinüçyüzotuzbirinci"},
            {"test": 116330, "to": "ordinal",
             "expected": u"yüzonaltıbinüçyüzotuzuncu"},
            {"test": 100000, "to": "ordinal", "expected": u"yüzbininci"},
            {"test": 501000, "to": "ordinal",
             "expected": u"beşyüzbirbininci"},
            {"test": 1000111, "to": "ordinal",
             "expected": u"birmilyonyüzonbirinci"},
            {"test": 111000111, "to": "ordinal",
             "expected": u"yüzonbirmilyonyüzonbirinci"},
            {"test": 111001111, "to": "ordinal",
             "expected": u"yüzonbirmilyonbinyüzonbirinci"},
            {"test": 111111111, "to": "ordinal",
             "expected": u"yüzonbirmilyonyüzonbirbinyüzonbirinci"},
            {"test": 100001000, "to": "ordinal",
             "expected": u"yüzmilyonbininci"},
            {"test": 100001001, "to": "ordinal",
             "expected": u"yüzmilyonbinbirinci"},
            {"test": 100010000, "to": "ordinal",
             "expected": u"yüzmilyononbininci"},
            {"test": 100010001, "to": "ordinal",
             "expected": u"yüzmilyononbinbirinci"},
            {"test": 100011000, "to": "ordinal",
             "expected": u"yüzmilyononbirbininci"},
            {"test": 100011001, "to": "ordinal",
             "expected": u"yüzmilyononbirbinbirinci"},
            {"test": 101011001, "to": "ordinal",
             "expected": u"yüzbirmilyononbirbinbirinci"},
            {"test": 101011010, "to": "ordinal",
             "expected": u"yüzbirmilyononbirbinonuncu"},
            {"test": 1101011010, "to": "ordinal",
             "expected": u"birmilyaryüzbirmilyononbirbinonuncu"},
            {"test": 101101011010, "to": "ordinal",
             "expected": u"yüzbirmilyaryüzbirmilyononbirbinonuncu"},
            {"test": 1000000000001, "to": "ordinal",
             "expected": u"birtrilyonbirinci"},
            {"test": 1.2, "to": "ordinal", "expected": u""},
            {"test": 1.3, "to": "ordinal", "expected": u""},
            {"test": 3000, "to": "ordinal", "expected": u"üçbininci"},
            {"test": 120000, "to": "ordinal", "expected": u"yüzyirmibininci"},
            {"test": 1002002, "to": "ordinal",
             "expected": u"birmilyonikibinikinci"},
            {"test": 1003000, "to": "ordinal",
             "expected": u"birmilyonüçbininci"},
            {"test": 1200000, "to": "ordinal",
             "expected": u"birmilyonikiyüzbininci"},
            {"test": 0, "to": "cardinal", "expected": u"sıfır"},
            {"test": 1, "to": "cardinal", "expected": u"bir"},
            {"test": 2, "to": "cardinal", "expected": u"iki"},
            {"test": 9, "to": "cardinal", "expected": u"dokuz"},
            {"test": 10, "to": "cardinal", "expected": u"on"},
            {"test": 11, "to": "cardinal", "expected": u"onbir"},
            {"test": 44, "to": "cardinal", "expected": u"kırkdört"},
            {"test": 100, "to": "cardinal", "expected": u"yüz"},
            {"test": 101, "to": "cardinal", "expected": u"yüzbir"},
            {"test": 103, "to": "cardinal", "expected": u"yüzüç"},
            {"test": 110, "to": "cardinal", "expected": u"yüzon"},
            {"test": 111, "to": "cardinal", "expected": u"yüzonbir"},
            {"test": 1000, "to": "cardinal", "expected": u"bin"},
            {"test": 1001, "to": "cardinal", "expected": u"binbir"},
            {"test": 1010, "to": "cardinal", "expected": u"binon"},
            {"test": 1011, "to": "cardinal", "expected": u"binonbir"},
            {"test": 1100, "to": "cardinal", "expected": u"binyüz"},
            {"test": 1110, "to": "cardinal", "expected": u"binyüzon"},
            {"test": 2341, "to": "cardinal",
             "expected": u"ikibinüçyüzkırkbir"},
            {"test": 10000, "to": "cardinal", "expected": u"onbin"},
            {"test": 10010, "to": "cardinal", "expected": u"onbinon"},
            {"test": 10100, "to": "cardinal", "expected": u"onbinyüz"},
            {"test": 10110, "to": "cardinal", "expected": u"onbinyüzon"},
            {"test": 11000, "to": "cardinal", "expected": u"onbirbin"},
            {"test": 35000, "to": "cardinal", "expected": u"otuzbeşbin"},
            {"test": 116331, "to": "cardinal",
             "expected": u"yüzonaltıbinüçyüzotuzbir"},
            {"test": 116330, "to": "cardinal",
             "expected": u"yüzonaltıbinüçyüzotuz"},
            {"test": 500000, "to": "cardinal", "expected": u"beşyüzbin"},
            {"test": 501000, "to": "cardinal", "expected": u"beşyüzbirbin"},
            {"test": 1000111, "to": "cardinal",
             "expected": u"birmilyonyüzonbir"},
            {"test": 111000111, "to": "cardinal",
             "expected": u"yüzonbirmilyonyüzonbir"},
            {"test": 111001111, "to": "cardinal",
             "expected": u"yüzonbirmilyonbinyüzonbir"},
            {"test": 111111111, "to": "cardinal",
             "expected": u"yüzonbirmilyonyüzonbirbinyüzonbir"},
            {"test": 100001000, "to": "cardinal",
             "expected": u"yüzmilyonbin"},
            {"test": 100001001, "to": "cardinal",
             "expected": u"yüzmilyonbinbir"},
            {"test": 100010000, "to": "cardinal",
             "expected": u"yüzmilyononbin"},
            {"test": 100010001, "to": "cardinal",
             "expected": u"yüzmilyononbinbir"},
            {"test": 100011000, "to": "cardinal",
             "expected": u"yüzmilyononbirbin"},
            {"test": 100011001, "to": "cardinal",
             "expected": u"yüzmilyononbirbinbir"},
            {"test": 101011001, "to": "cardinal",
             "expected": u"yüzbirmilyononbirbinbir"},
            {"test": 101011010, "to": "cardinal",
             "expected": u"yüzbirmilyononbirbinon"},
            {"test": 1101011010, "to": "cardinal",
             "expected": u"birmilyaryüzbirmilyononbirbinon"},
            {"test": 101101011010, "to": "cardinal",
             "expected": u"yüzbirmilyaryüzbirmilyononbirbinon"},
            {"test": 1000000000001, "to": "cardinal",
             "expected": u"birtrilyonbir"},
            {"test": 0.01, "to": "cardinal", "expected": u"sıfırvirgülbir"},
            {"test": 0.21, "to": "cardinal",
             "expected": u"sıfırvirgülyirmibir"},
            {"test": 0.1, "to": "cardinal", "expected": u"sıfırvirgülon"},
            {"test": 1.01, "to": "cardinal", "expected": u"birvirgülbir"},
            {"test": 1.1, "to": "cardinal", "expected": u"birvirgülon"},
            {"test": 1.21, "to": "cardinal",
             "expected": u"birvirgülyirmibir"},
            {"test": 101101011010.02, "to": "cardinal",
             "expected": u"yüzbirmilyaryüzbirmilyononbirbinonvirgüliki"},
            {"test": 101101011010.2, "to": "cardinal",
             "expected": u"yüzbirmilyaryüzbirmilyononbirbinonvirgülyirmi"},
            {"test": 10, "to": "ordinal_num", "expected": u"10uncu"},
            {"test": 1, "to": "ordinal_num", "expected": u"1inci"},
            {"test": 3, "to": "ordinal_num", "expected": u"3üncü"},
            {"test": 6, "to": "ordinal_num", "expected": u"6ıncı"},
            {"test": -5, "to": "cardinal", "expected": u"eksibeş"},
            {"test": -55, "to": "cardinal", "expected": u"eksiellibeş"},
            {"test": -576, "to": "cardinal",
             "expected": u"eksibeşyüzyetmişaltı"},
            {"test": -3, "to": "currency", "expected": u"eksiüçlira"},
        ]

        for casedata in testcases:
            self.assertEqual(
                num2words(casedata["test"],
                          lang=testlang,
                          to=casedata["to"]),
                casedata["expected"])



# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from __future__ import unicode_literals

from decimal import Decimal
from unittest import TestCase

from num2words import num2words
from num2words.lang_PT import Num2Word_PT


class Num2WordsPTTest(TestCase):
    def setUp(self):
        super(Num2WordsPTTest, self).setUp()
        self.n2w = Num2Word_PT()

    def test_cardinal_integer(self):
        self.assertEqual(num2words(1, lang='pt'), 'um')
        self.assertEqual(num2words(2, lang='pt'), 'dois')
        self.assertEqual(num2words(3, lang='pt'), 'três')
        self.assertEqual(num2words(4, lang='pt'), 'quatro')
        self.assertEqual(num2words(5, lang='pt'), 'cinco')
        self.assertEqual(num2words(6, lang='pt'), 'seis')
        self.assertEqual(num2words(7, lang='pt'), 'sete')
        self.assertEqual(num2words(8, lang='pt'), 'oito')
        self.assertEqual(num2words(9, lang='pt'), 'nove')
        self.assertEqual(num2words(10, lang='pt'), 'dez')
        self.assertEqual(num2words(11, lang='pt'), 'onze')
        self.assertEqual(num2words(12, lang='pt'), 'doze')
        self.assertEqual(num2words(13, lang='pt'), 'treze')
        self.assertEqual(num2words(14, lang='pt'), 'catorze')
        self.assertEqual(num2words(15, lang='pt'), 'quinze')
        self.assertEqual(num2words(16, lang='pt'), 'dezasseis')
        self.assertEqual(num2words(17, lang='pt'), 'dezassete')
        self.assertEqual(num2words(18, lang='pt'), 'dezoito')
        self.assertEqual(num2words(19, lang='pt'), 'dezanove')
        self.assertEqual(num2words(20, lang='pt'), 'vinte')

        self.assertEqual(num2words(21, lang='pt'), 'vinte e um')
        self.assertEqual(num2words(22, lang='pt'), 'vinte e dois')
        self.assertEqual(num2words(35, lang='pt'), 'trinta e cinco')
        self.assertEqual(num2words(99, lang='pt'), 'noventa e nove')

        self.assertEqual(num2words(100, lang='pt'), 'cem')
        self.assertEqual(num2words(101, lang='pt'), 'cento e um')
        self.assertEqual(num2words(128, lang='pt'), 'cento e vinte e oito')
        self.assertEqual(num2words(713, lang='pt'), 'setecentos e treze')

        self.assertEqual(num2words(1000, lang='pt'), 'mil')
        self.assertEqual(num2words(1001, lang='pt'), 'mil e um')
        self.assertEqual(num2words(1111, lang='pt'), 'mil cento e onze')
        self.assertEqual(
            num2words(2114, lang='pt'), 'dois mil cento e catorze'
        )
        self.assertEqual(
            num2words(2200, lang='pt'),
            'dois mil e duzentos'
        )
        self.assertEqual(
            num2words(2230, lang='pt'),
            'dois mil duzentos e trinta'
        )
        self.assertEqual(
            num2words(73400, lang='pt'),
            'setenta e três mil e quatrocentos'
        )
        self.assertEqual(
            num2words(73421, lang='pt'),
            'setenta e três mil quatrocentos e vinte e um'
        )
        self.assertEqual(num2words(100000, lang='pt'), 'cem mil')
        self.assertEqual(
            num2words(250050, lang='pt'),
            'duzentos e cinquenta mil e cinquenta'
        )
        self.assertEqual(
            num2words(6000000, lang='pt'), 'seis milhões'
        )
        self.assertEqual(
            num2words(100000000, lang='pt'), 'cem milhões'
        )
        self.assertEqual(
            num2words(19000000000, lang='pt'), 'dezanove mil milhões'
        )
        self.assertEqual(
            num2words(145000000002, lang='pt'),
            'cento e quarenta e cinco mil milhões e dois'
        )
        self.assertEqual(
            num2words(4635102, lang='pt'),
            'quatro milhões seiscentos e trinta e cinco mil cento e dois'
        )
        self.assertEqual(
            num2words(145254635102, lang='pt'),
            'cento e quarenta e cinco mil duzentos e cinquenta e quatro '
            'milhões seiscentos e trinta e cinco mil cento e dois'
        )
        self.assertEqual(
            num2words(1000000000000, lang='pt'),
            'um bilião'
        )
        self.assertEqual(
            num2words(2000000000000, lang='pt'),
            'dois biliões'
        )
        self.assertEqual(
            num2words(1000000000000000, lang='pt'),
            'mil biliões'
        )
        self.assertEqual(
            num2words(2000000000000000, lang='pt'),
            'dois mil biliões'
        )
        self.assertEqual(
            num2words(1000000000000000000, lang='pt'),
            'um trilião'
        )
        self.assertEqual(
            num2words(2000000000000000000, lang='pt'),
            'dois triliões'
        )

    def test_cardinal_integer_negative(self):
        self.assertEqual(num2words(-1, lang='pt'), 'menos um')
        self.assertEqual(
            num2words(-256, lang='pt'), 'menos duzentos e cinquenta e seis'
        )
        self.assertEqual(num2words(-1000, lang='pt'), 'menos mil')
        self.assertEqual(num2words(-1000000, lang='pt'), 'menos um milhão')
        self.assertEqual(
            num2words(-1234567, lang='pt'),
            'menos um milhão duzentos e trinta e quatro mil quinhentos e '
            'sessenta e sete'
        )

    def test_cardinal_float(self):
        self.assertEqual(num2words(Decimal('1.00'), lang='pt'), 'um')
        self.assertEqual(num2words(
            Decimal('1.01'), lang='pt'), 'um vírgula zero um')
        self.assertEqual(num2words(
            Decimal('1.035'), lang='pt'), 'um vírgula zero três cinco'
        )
        self.assertEqual(num2words(
            Decimal('1.35'), lang='pt'), 'um vírgula três cinco'
        )
        self.assertEqual(
            num2words(Decimal('3.14159'), lang='pt'),
            'três vírgula um quatro um cinco nove'
        )
        self.assertEqual(
            num2words(Decimal('101.22'), lang='pt'),
            'cento e um vírgula dois dois'
        )
        self.assertEqual(
            num2words(Decimal('2345.75'), lang='pt'),
            'dois mil trezentos e quarenta e cinco vírgula sete cinco')

    def test_cardinal_float_negative(self):
        self.assertEqual(
            num2words(Decimal('-2.34'), lang='pt'),
            'menos dois vírgula três quatro'
        )
        self.assertEqual(
            num2words(Decimal('-9.99'), lang='pt'),
            'menos nove vírgula nove nove'
        )
        self.assertEqual(
            num2words(Decimal('-7.01'), lang='pt'),
            'menos sete vírgula zero um'
        )
        self.assertEqual(
            num2words(Decimal('-222.22'), lang='pt'),
            'menos duzentos e vinte e dois vírgula dois dois'
        )

    def test_ordinal(self):
        self.assertEqual(num2words(1, lang='pt', ordinal=True), 'primeiro')
        self.assertEqual(num2words(2, lang='pt', ordinal=True), 'segundo')
        self.assertEqual(num2words(3, lang='pt', ordinal=True), 'terceiro')
        self.assertEqual(num2words(4, lang='pt', ordinal=True), 'quarto')
        self.assertEqual(num2words(5, lang='pt', ordinal=True), 'quinto')
        self.assertEqual(num2words(6, lang='pt', ordinal=True), 'sexto')
        self.assertEqual(num2words(7, lang='pt', ordinal=True), 'sétimo')
        self.assertEqual(num2words(8, lang='pt', ordinal=True), 'oitavo')
        self.assertEqual(num2words(9, lang='pt', ordinal=True), 'nono')
        self.assertEqual(num2words(10, lang='pt', ordinal=True), 'décimo')
        self.assertEqual(
            num2words(11, lang='pt', ordinal=True), 'décimo primeiro'
        )
        self.assertEqual(
            num2words(12, lang='pt', ordinal=True), 'décimo segundo'
        )
        self.assertEqual(
            num2words(13, lang='pt', ordinal=True), 'décimo terceiro'
        )
        self.assertEqual(
            num2words(14, lang='pt', ordinal=True), 'décimo quarto'
        )
        self.assertEqual(
            num2words(15, lang='pt', ordinal=True), 'décimo quinto'
        )
        self.assertEqual(
            num2words(16, lang='pt', ordinal=True), 'décimo sexto'
        )
        self.assertEqual(
            num2words(17, lang='pt', ordinal=True), 'décimo sétimo'
        )
        self.assertEqual(
            num2words(18, lang='pt', ordinal=True), 'décimo oitavo'
        )
        self.assertEqual(
            num2words(19, lang='pt', ordinal=True), 'décimo nono'
        )
        self.assertEqual(
            num2words(20, lang='pt', ordinal=True), 'vigésimo'
        )

        self.assertEqual(
            num2words(21, lang='pt', ordinal=True), 'vigésimo primeiro'
        )
        self.assertEqual(
            num2words(22, lang='pt', ordinal=True), 'vigésimo segundo'
        )
        self.assertEqual(
            num2words(35, lang='pt', ordinal=True), 'trigésimo quinto'
        )
        self.assertEqual(
            num2words(99, lang='pt', ordinal=True), 'nonagésimo nono'
        )

        self.assertEqual(
            num2words(100, lang='pt', ordinal=True), 'centésimo'
        )
        self.assertEqual(
            num2words(101, lang='pt', ordinal=True), 'centésimo primeiro'
        )
        self.assertEqual(
            num2words(128, lang='pt', ordinal=True),
            'centésimo vigésimo oitavo'
        )
        self.assertEqual(
            num2words(713, lang='pt', ordinal=True),
            'septigentésimo décimo terceiro'
        )

        self.assertEqual(
            num2words(1000, lang='pt', ordinal=True), 'milésimo'
        )
        self.assertEqual(
            num2words(1001, lang='pt', ordinal=True), 'milésimo primeiro'
        )
        self.assertEqual(
            num2words(1111, lang='pt', ordinal=True),
            'milésimo centésimo décimo primeiro'
        )
        self.assertEqual(
            num2words(2114, lang='pt', ordinal=True),
            'segundo milésimo centésimo décimo quarto'
        )
        self.assertEqual(
            num2words(73421, lang='pt', ordinal=True),
            'septuagésimo terceiro milésimo quadrigentésimo vigésimo primeiro'
        )

        self.assertEqual(
            num2words(100000, lang='pt', ordinal=True),
            'centésimo milésimo'
        )
        self.assertEqual(
            num2words(250050, lang='pt', ordinal=True),
            'ducentésimo quinquagésimo milésimo quinquagésimo'
        )
        self.assertEqual(
            num2words(6000000, lang='pt', ordinal=True), 'sexto milionésimo'
        )
        self.assertEqual(
            num2words(19000000000, lang='pt', ordinal=True),
            'décimo nono milésimo milionésimo'
        )
        self.assertEqual(
            num2words(145000000002, lang='pt', ordinal=True),
            'centésimo quadragésimo quinto milésimo milionésimo segundo'
        )

    def test_currency_integer(self):
        self.assertEqual(self.n2w.to_currency(1.00), 'um euro')
        self.assertEqual(self.n2w.to_currency(2.00), 'dois euros')
        self.assertEqual(self.n2w.to_currency(3.00), 'três euros')
        self.assertEqual(self.n2w.to_currency(4.00), 'quatro euros')
        self.assertEqual(self.n2w.to_currency(5.00), 'cinco euros')
        self.assertEqual(self.n2w.to_currency(6.00), 'seis euros')
        self.assertEqual(self.n2w.to_currency(7.00), 'sete euros')
        self.assertEqual(self.n2w.to_currency(8.00), 'oito euros')
        self.assertEqual(self.n2w.to_currency(9.00), 'nove euros')
        self.assertEqual(self.n2w.to_currency(10.00), 'dez euros')
        self.assertEqual(self.n2w.to_currency(11.00), 'onze euros')
        self.assertEqual(self.n2w.to_currency(12.00), 'doze euros')
        self.assertEqual(self.n2w.to_currency(13.00), 'treze euros')
        self.assertEqual(self.n2w.to_currency(14.00), 'catorze euros')
        self.assertEqual(self.n2w.to_currency(15.00), 'quinze euros')
        self.assertEqual(self.n2w.to_currency(16.00), 'dezasseis euros')
        self.assertEqual(self.n2w.to_currency(17.00), 'dezassete euros')
        self.assertEqual(self.n2w.to_currency(18.00), 'dezoito euros')
        self.assertEqual(self.n2w.to_currency(19.00), 'dezanove euros')
        self.assertEqual(self.n2w.to_currency(20.00), 'vinte euros')

        self.assertEqual(self.n2w.to_currency(21.00), 'vinte e um euros')
        self.assertEqual(self.n2w.to_currency(22.00), 'vinte e dois euros')
        self.assertEqual(self.n2w.to_currency(35.00), 'trinta e cinco euros')
        self.assertEqual(self.n2w.to_currency(99.00), 'noventa e nove euros')

        self.assertEqual(self.n2w.to_currency(100.00), 'cem euros')
        self.assertEqual(self.n2w.to_currency(101.00), 'cento e um euros')
        self.assertEqual(
            self.n2w.to_currency(128.00), 'cento e vinte e oito euros'
        )
        self.assertEqual(
            self.n2w.to_currency(713.00), 'setecentos e treze euros')

        self.assertEqual(self.n2w.to_currency(1000.00), 'mil euros')
        self.assertEqual(self.n2w.to_currency(1001.00), 'mil e um euros')
        self.assertEqual(
            self.n2w.to_currency(1111.00), 'mil cento e onze euros')
        self.assertEqual(
            self.n2w.to_currency(2114.00), 'dois mil cento e catorze euros'
        )
        self.assertEqual(
            self.n2w.to_currency(73421.00),
            'setenta e três mil quatrocentos e vinte e um euros'
        )

        self.assertEqual(self.n2w.to_currency(100000.00), 'cem mil euros')
        self.assertEqual(
            self.n2w.to_currency(250050.00),
            'duzentos e cinquenta mil e cinquenta euros'
        )
        self.assertEqual(
            self.n2w.to_currency(6000000.00), 'seis milhões de euros'
        )
        self.assertEqual(
            self.n2w.to_currency(19000000000.00),
            'dezanove mil milhões de euros'
        )
        self.assertEqual(
            self.n2w.to_currency(145000000002.00),
            'cento e quarenta e cinco mil milhões e dois euros'
        )
        self.assertEqual(self.n2w.to_currency(1.00, currency='USD'),
                         'um dólar')
        self.assertEqual(self.n2w.to_currency(1.50, currency='USD'),
                         'um dólar e cinquenta cêntimos')
        with self.assertRaises(NotImplementedError):
            self.n2w.to_currency(1.00, currency='CHF')

    def test_currency_integer_negative(self):
        self.assertEqual(self.n2w.to_currency(-1.00), 'menos um euro')
        self.assertEqual(
            self.n2w.to_currency(-256.00),
            'menos duzentos e cinquenta e seis euros'
        )
        self.assertEqual(self.n2w.to_currency(-1000.00), 'menos mil euros')
        self.assertEqual(
            self.n2w.to_currency(-1000000.00), 'menos um milhão de euros'
        )
        self.assertEqual(
            self.n2w.to_currency(-1234567.00),
            'menos um milhão duzentos e trinta e quatro mil quinhentos e '
            'sessenta e sete euros'
        )

    def test_currency_float(self):
        self.assertEqual(self.n2w.to_currency(Decimal('1.00')), 'um euro')
        self.assertEqual(
            self.n2w.to_currency(Decimal('1.01')), 'um euro e um cêntimo'
        )
        self.assertEqual(
            self.n2w.to_currency(Decimal('1.03')), 'um euro e três cêntimos'
        )
        self.assertEqual(
            self.n2w.to_currency(Decimal('1.35')),
            'um euro e trinta e cinco cêntimos'
        )
        self.assertEqual(
            self.n2w.to_currency(Decimal('3.14')),
            'três euros e catorze cêntimos'
        )
        self.assertEqual(
            self.n2w.to_currency(Decimal('101.22')),
            'cento e um euros e vinte e dois cêntimos'
        )
        self.assertEqual(
            self.n2w.to_currency(Decimal('2345.75')),
            'dois mil trezentos e quarenta e cinco euros e setenta e cinco '
            'cêntimos'
        )

    def test_currency_float_negative(self):
        self.assertEqual(
            self.n2w.to_currency(Decimal('-2.34')),
            'menos dois euros e trinta e quatro cêntimos'
        )
        self.assertEqual(
            self.n2w.to_currency(Decimal('-9.99')),
            'menos nove euros e noventa e nove cêntimos'
        )
        self.assertEqual(
            self.n2w.to_currency(Decimal('-7.01')),
            'menos sete euros e um cêntimo'
        )
        self.assertEqual(
            self.n2w.to_currency(Decimal('-222.22')),
            'menos duzentos e vinte e dois euros e vinte e dois cêntimos'
        )

    def test_year(self):
        self.assertEqual(self.n2w.to_year(1001), 'mil e um')
        self.assertEqual(
            self.n2w.to_year(1789), 'mil setecentos e oitenta e nove'
        )
        self.assertEqual(
            self.n2w.to_year(1942), 'mil novecentos e quarenta e dois'
        )
        self.assertEqual(
            self.n2w.to_year(1984), 'mil novecentos e oitenta e quatro'
        )
        self.assertEqual(self.n2w.to_year(2000), 'dois mil')
        self.assertEqual(self.n2w.to_year(2001), 'dois mil e um')
        self.assertEqual(self.n2w.to_year(2016), 'dois mil e dezasseis')

    def test_year_negative(self):
        self.assertEqual(self.n2w.to_year(-30), 'trinta antes de Cristo')
        self.assertEqual(
            self.n2w.to_year(-744),
            'setecentos e quarenta e quatro antes de Cristo'
        )
        self.assertEqual(self.n2w.to_year(-10000), 'dez mil antes de Cristo')

    def test_to_ordinal_num(self):
        self.assertEqual(self.n2w.to_ordinal_num(1), '1º')
        self.assertEqual(self.n2w.to_ordinal_num(100), '100º')



# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from unittest import TestCase

from num2words import num2words


class Num2WordsENTest(TestCase):
    def test_and_join_199(self):
        # ref https://github.com/savoirfairelinux/num2words/issues/8
        self.assertEqual(num2words(199), "one hundred and ninety-nine")

    def test_ordinal(self):
        self.assertEqual(
            num2words(0, lang='en', to='ordinal'),
            'zeroth'
        )
        self.assertEqual(
            num2words(1, lang='en', to='ordinal'),
            'first'
        )
        self.assertEqual(
            num2words(13, lang='en', to='ordinal'),
            'thirteenth'
        )
        self.assertEqual(
            num2words(22, lang='en', to='ordinal'),
            'twenty-second'
        )
        self.assertEqual(
            num2words(12, lang='en', to='ordinal'),
            'twelfth'
        )
        self.assertEqual(
            num2words(130, lang='en', to='ordinal'),
            'one hundred and thirtieth'
        )
        self.assertEqual(
            num2words(1003, lang='en', to='ordinal'),
            'one thousand and third'
        )

    def test_ordinal_num(self):
        self.assertEqual(num2words(10, lang='en', to='ordinal_num'), '10th')
        self.assertEqual(num2words(21, lang='en', to='ordinal_num'), '21st')
        self.assertEqual(num2words(102, lang='en', to='ordinal_num'), '102nd')
        self.assertEqual(num2words(73, lang='en', to='ordinal_num'), '73rd')

    def test_cardinal_for_float_number(self):
        # issue 24
        self.assertEqual(num2words(12.5), "twelve point five")
        self.assertEqual(num2words(12.51), "twelve point five one")
        self.assertEqual(num2words(12.53), "twelve point five three")
        self.assertEqual(num2words(12.59), "twelve point five nine")

    def test_overflow(self):
        with self.assertRaises(OverflowError):
            num2words("1000000000000000000000000000000000000000000000000000000"
                      "0000000000000000000000000000000000000000000000000000000"
                      "0000000000000000000000000000000000000000000000000000000"
                      "0000000000000000000000000000000000000000000000000000000"
                      "0000000000000000000000000000000000000000000000000000000"
                      "00000000000000000000000000000000")

    def test_to_currency(self):
        self.assertEqual(
            num2words('38.4', lang='en', to='currency', separator=' and',
                      cents=False, currency='USD'),
            "thirty-eight dollars and 40 cents"
        )
        self.assertEqual(
            num2words('0', lang='en', to='currency', separator=' and',
                      cents=False, currency='USD'),
            "zero dollars and 00 cents"
        )

        self.assertEqual(
            num2words('1.01', lang='en', to='currency', separator=' and',
                      cents=True, currency='USD'),
            "one dollar and one cent"
        )

        self.assertEqual(
            num2words('4778.00', lang='en', to='currency', separator=' and',
                      cents=True, currency='USD', adjective=True),
            'four thousand, seven hundred and seventy-eight US dollars'
            ' and zero cents')

        self.assertEqual(
            num2words('4778.00', lang='en', to='currency', separator=' and',
                      cents=True, currency='USD'),
            'four thousand, seven hundred and seventy-eight dollars and'
            ' zero cents')

        self.assertEqual(
            num2words('1.1', lang='en', to='currency', separator=' and',
                      cents=True, currency='MXN'),
            "one peso and ten cents"
        )

        self.assertEqual(
            num2words('158.3', lang='en', to='currency', separator=' and',
                      cents=True, currency='MXN'),
            "one hundred and fifty-eight pesos and thirty cents"
        )

        self.assertEqual(
            num2words('2000.00', lang='en', to='currency', separator=' and',
                      cents=True, currency='MXN'),
            "two thousand pesos and zero cents"
        )

        self.assertEqual(
            num2words('4.01', lang='en', to='currency', separator=' and',
                      cents=True, currency='MXN'),
            "four pesos and one cent"
        )

        self.assertEqual(
            num2words('2000.00', lang='en', to='currency', separator=' and',
                      cents=True, currency='UZS'),
            "two thousand sums and zero tiyins"
        )

    def test_to_year(self):
        # issue 141
        # "e2 e2"
        self.assertEqual(num2words(1990, lang='en', to='year'),
                         'nineteen ninety')
        self.assertEqual(num2words(5555, lang='en', to='year'),
                         'fifty-five fifty-five')
        self.assertEqual(num2words(2017, lang='en', to='year'),
                         'twenty seventeen')
        self.assertEqual(num2words(1066, lang='en', to='year'),
                         'ten sixty-six')
        self.assertEqual(num2words(1865, lang='en', to='year'),
                         'eighteen sixty-five')
        # "e3 and e1"; "e2 oh-e1"; "e3"
        self.assertEqual(num2words(3000, lang='en', to='year'),
                         'three thousand')
        self.assertEqual(num2words(2001, lang='en', to='year'),
                         'two thousand and one')
        self.assertEqual(num2words(1901, lang='en', to='year'),
                         'nineteen oh-one')
        self.assertEqual(num2words(2000, lang='en', to='year'),
                         'two thousand')
        self.assertEqual(num2words(905, lang='en', to='year'),
                         'nine oh-five')
        # "e2 hundred"; "e3"
        self.assertEqual(num2words(6600, lang='en', to='year'),
                         'sixty-six hundred')
        self.assertEqual(num2words(1900, lang='en', to='year'),
                         'nineteen hundred')
        self.assertEqual(num2words(600, lang='en', to='year'),
                         'six hundred')
        self.assertEqual(num2words(50, lang='en', to='year'),
                         'fifty')
        self.assertEqual(num2words(0, lang='en', to='year'),
                         'zero')
        # suffixes
        self.assertEqual(num2words(-44, lang='en', to='year'),
                         'forty-four BC')
        self.assertEqual(num2words(-44, lang='en', to='year', suffix='BCE'),
                         'forty-four BCE')
        self.assertEqual(num2words(1, lang='en', to='year', suffix='AD'),
                         'one AD')
        self.assertEqual(num2words(66, lang='en', to='year',
                                   suffix='m.y.a.'),
                         'sixty-six m.y.a.')
        self.assertEqual(num2words(-66000000, lang='en', to='year'),
                         'sixty-six million BC')



# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from __future__ import unicode_literals

from .base import Num2Word_Base
from .utils import get_digits, splitbyx

ZERO = ('nulis',)

ONES_FEMININE = {
    1: ('viena',),
    2: ('dvi',),
    3: ('trys',),
    4: ('keturios',),
    5: ('penkios',),
    6: ('šešios',),
    7: ('septynios',),
    8: ('aštuonios',),
    9: ('devynios',),
}

ONES = {
    1: ('vienas',),
    2: ('du',),
    3: ('trys',),
    4: ('keturi',),
    5: ('penki',),
    6: ('šeši',),
    7: ('septyni',),
    8: ('aštuoni',),
    9: ('devyni',),
}

TENS = {
    0: ('dešimt',),
    1: ('vienuolika',),
    2: ('dvylika',),
    3: ('trylika',),
    4: ('keturiolika',),
    5: ('penkiolika',),
    6: ('šešiolika',),
    7: ('septyniolika',),
    8: ('aštuoniolika',),
    9: ('devyniolika',),
}

TWENTIES = {
    2: ('dvidešimt',),
    3: ('trisdešimt',),
    4: ('keturiasdešimt',),
    5: ('penkiasdešimt',),
    6: ('šešiasdešimt',),
    7: ('septyniasdešimt',),
    8: ('aštuoniasdešimt',),
    9: ('devyniasdešimt',),
}

HUNDRED = ('šimtas', 'šimtai')

THOUSANDS = {
    1: ('tūkstantis', 'tūkstančiai', 'tūkstančių'),
    2: ('milijonas', 'milijonai', 'milijonų'),
    3: ('milijardas', 'milijardai', 'milijardų'),
    4: ('trilijonas', 'trilijonai', 'trilijonų'),
    5: ('kvadrilijonas', 'kvadrilijonai', 'kvadrilijonų'),
    6: ('kvintilijonas', 'kvintilijonai', 'kvintilijonų'),
    7: ('sikstilijonas', 'sikstilijonai', 'sikstilijonų'),
    8: ('septilijonas', 'septilijonai', 'septilijonų'),
    9: ('oktilijonas', 'oktilijonai', 'oktilijonų'),
    10: ('naintilijonas', 'naintilijonai', 'naintilijonų'),
}

GENERIC_CENTS = ('centas', 'centai', 'centų')


class Num2Word_LT(Num2Word_Base):
    CURRENCY_FORMS = {
        'LTL': (('litas', 'litai', 'litų'), GENERIC_CENTS),
        'EUR': (('euras', 'eurai', 'eurų'), GENERIC_CENTS),
        'USD': (('doleris', 'doleriai', 'dolerių'), GENERIC_CENTS),
        'GBP': (
            ('svaras sterlingų', 'svarai sterlingų', 'svarų sterlingų'),
            ('pensas', 'pensai', 'pensų')
        ),
        'PLN': (
            ('zlotas', 'zlotai', 'zlotų'),
            ('grašis', 'grašiai', 'grašių')),
        'RUB': (
            ('rublis', 'rubliai', 'rublių'),
            ('kapeika', 'kapeikos', 'kapeikų')
        ),
    }

    def setup(self):
        self.negword = "minus"
        self.pointword = "kablelis"

    def pluralize(self, n, forms):
        n1, n2, n3 = get_digits(n)
        if n2 == 1 or n1 == 0 or n == 0:
            return forms[2]
        elif n1 == 1:
            return forms[0]
        else:
            return forms[1]

    def to_cardinal(self, number):
        n = str(number).replace(',', '.')
        base_str, n = self.parse_minus(n)
        if '.' in n:
            left, right = n.split('.')
            leading_zero_count = len(right) - len(right.lstrip('0'))
            decimal_part = ((ZERO[0] + ' ') * leading_zero_count +
                            self._int2word(int(right)))
            return '%s%s %s %s' % (
                base_str,
                self._int2word(int(left)),
                self.pointword,
                decimal_part
            )
        else:
            return "%s%s" % (base_str, self._int2word(int(n)))

    def to_ordinal(self, number):
        raise NotImplementedError()

    def _cents_verbose(self, number, currency):
        return self._int2word(number, currency == 'RUB')

    def _int2word(self, n, feminine=False):
        if n == 0:
            return ZERO[0]

        words = []
        chunks = list(splitbyx(str(n), 3))
        i = len(chunks)

        for x in chunks:
            i -= 1

            if x == 0:
                continue

            n1, n2, n3 = get_digits(x)

            if n3 > 0:
                words.append(ONES[n3][0])
                if n3 > 1:
                    words.append(HUNDRED[1])
                else:
                    words.append(HUNDRED[0])

            if n2 > 1:
                words.append(TWENTIES[n2][0])

            if n2 == 1:
                words.append(TENS[n1][0])
            elif n1 > 0:
                if (i == 1 or feminine and i == 0) and n < 1000:
                    words.append(ONES_FEMININE[n1][0])
                else:
                    words.append(ONES[n1][0])

            if i > 0:
                words.append(self.pluralize(x, THOUSANDS[i]))

        return ' '.join(words)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from __future__ import unicode_literals

import os
import unittest

import delegator

import num2words


class CliCaller(object):

    def __init__(self):
        self.cmd = os.path.realpath(os.path.join(os.path.dirname(__file__),
                                    "..", "bin", "num2words"))
        self.cmd_list = ["python", self.cmd]

    def run_cmd(self, *args):
        cmd_list = self.cmd_list + [str(arg) for arg in args]
        cmd = " ".join(cmd_list)
        return delegator.run(cmd)


class CliTestCase(unittest.TestCase):
    """Test the command line app"""

    def setUp(self):
        self.cli = CliCaller()

    def test_cli_help(self):
        """num2words without arguments should exit with status 1
        and show docopt's default short usage message
        """
        output = self.cli.run_cmd()
        self.assertEqual(output.return_code, 1)
        self.assertTrue(output.err.startswith('Usage:'))

    def test_cli_list_langs(self):
        """You should be able to list all available languages
        """
        output = self.cli.run_cmd('--list-languages')
        self.assertEqual(
            sorted(list(num2words.CONVERTER_CLASSES.keys())),
            [out for out in output.out.strip().splitlines() if out]
        )
        output = self.cli.run_cmd('-L')
        self.assertEqual(
            sorted(list(num2words.CONVERTER_CLASSES.keys())),
            [out for out in output.out.strip().splitlines() if out]
        )

    def test_cli_list_converters(self):
        """You should be able to list all available converters
        """
        output = self.cli.run_cmd('--list-converters')
        self.assertEqual(
            sorted(list(num2words.CONVERTES_TYPES)),
            [out for out in output.out.strip().splitlines() if out]
        )
        output = self.cli.run_cmd('-C')
        self.assertEqual(
            sorted(list(num2words.CONVERTES_TYPES)),
            [out for out in output.out.strip().splitlines() if out]
        )

    def test_cli_default_lang(self):
        """Default to english
        """
        output = self.cli.run_cmd(150)
        self.assertEqual(output.return_code, 0)
        self.assertEqual(
            output.out.strip(),
            "one hundred and fifty"
        )

    def test_cli_with_lang(self):
        """You should be able to specify a language
        """
        output = self.cli.run_cmd(150, '--lang', 'es')
        self.assertEqual(output.return_code, 0)
        self.assertEqual(
            output.out.strip(),
            "ciento cincuenta"
        )

    def test_cli_with_lang_to(self):
        """You should be able to specify a language and currency
        """
        output = self.cli.run_cmd(150.55, '--lang', 'es', '--to', 'currency')
        self.assertEqual(output.return_code, 0)
        self.assertEqual(
            (output.out.decode('utf-8') if hasattr(output.out, 'decode') else
             output.out).strip(),
            "ciento cincuenta euros con cincuenta y cinco céntimos"
        )



# -*- coding: utf-8 -*-
# Copyright (c) 2003, Taro Ogawa.  All Rights Reserved.
# Copyright (c) 2013, Savoir-faire Linux inc.  All Rights Reserved.

# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301 USA

from unittest import TestCase

from num2words import num2words


class Num2WordsIDTest(TestCase):
    def test_cardinal_for_natural_number(self):
        self.assertEqual(num2words(10, lang='id'), "sepuluh")
        self.assertEqual(num2words(11, lang='id'), "sebelas")
        self.assertEqual(num2words(108, lang='id'), "seratus delapan")
        self.assertEqual(num2words(1075, lang='id'), "seribu tujuh puluh lima")
        self.assertEqual(
            num2words(1087231, lang='id'),
            "satu juta delapan puluh tujuh ribu dua ratus tiga puluh satu"
        )
        self.assertEqual(
            num2words(1000000408, lang='id'),
            "satu miliar empat ratus delapan"
        )

    def test_cardinal_for_decimal_number(self):
        self.assertEqual(
            num2words(12.234, lang='id'), "dua belas koma dua tiga empat"
        )
        self.assertEqual(
            num2words(9.076, lang='id'), "sembilan koma nol tujuh enam"
        )

    def test_cardinal_for_negative_number(self):
        self.assertEqual(
            num2words(-923, lang='id'), "min sembilan ratus dua puluh tiga"
        )
        self.assertEqual(
            num2words(-0.234, lang='id'), "min nol koma dua tiga empat"
        )

    def test_ordinal_for_natural_number(self):
        self.assertEqual(num2words(1, ordinal=True, lang='id'), "pertama")
        self.assertEqual(num2words(10, ordinal=True, lang='id'), "kesepuluh")

    def test_ordinal_for_negative_number(self):
        self.assertRaises(TypeError, num2words, -12, ordinal=True, lang='id')

    def test_ordinal_for_floating_number(self):
        self.assertRaises(TypeError, num2words, 3.243, ordinal=True, lang='id')
